@@ -220,7 +220,7 @@ static CcpnStatus check_new_peak(Peak_list peak_list, int *buffer,
 				int *point, int ignore_peak, CcpnString error_msg)
 {
     int i, ndim = peak_list->ndim;
-    float *position;
+    float position[MAX_NDIM];
     Peak peak;
 
 /* check that not within buffer */
@@ -238,8 +238,6 @@ static CcpnStatus check_new_peak(Peak_list peak_list, int *buffer,
 /* have new peak, add to peak_list */
 
     CHECK_STATUS(add_peak_peak_list(peak_list, &peak, error_msg));
-    sprintf(error_msg, "allocating peak position memory");
-    MALLOC(position, float, ndim);
 
     for (i = 0; i < ndim; i++)
 	position[i] = point[i] + 1;
