@@ -14,6 +14,16 @@ typedef struct _CpmgParam
     float *y;
 }  Cpmg_param;
 
+#ifdef WIN32
+double acosh(double x)
+{
+    if (x < 1)
+        return 0.0; /* arbitrary */
+      
+    return log(x + sqrt(x*x-1));
+}
+#endif
+
 static float diff2(int n, float *x, float *y, float *params)
 {
     int i;
