@@ -776,10 +776,24 @@ static void init_params_fit(int method, int n,
 	    }
 	}
 
+/***
+	xmin = xmax;
+	y_at_xmin = y_at_xmax;
+	for (i = 0; i < n; i++)
+	{
+	    if (x[i] > 0 && x[i] < xmin)
+	    {
+		xmin = x[i];
+		y_at_xmin = y[i];
+	    }
+	}
+***/
+
 /*
 	params_fit[0] = 0.5 * xmax;
 */
 
+/**
 	done = CCPN_FALSE;
 	if (xmax > 1)
 	{
@@ -794,16 +808,29 @@ static void init_params_fit(int method, int n,
 		}
 	    }
 	}
+**/
 
+/**
 	if (done && (xmax2 > 1))
 	{
 	    params_fit[1] = (y_at_xmax-y_at_xmax2)/(y_at_xmax2/xmax2 - y_at_xmax/xmax);
 	    params_fit[0] = 0.5*y_at_xmax*(1+xmax/params_fit[1]);
 	}
 	else
+**/
 	{
 	    params_fit[0] = y_at_xmax;
-	    params_fit[1] = 1.1;
+/***
+	    params_fit[0] = 0.5 * y_at_xmax;
+	    if (y_at_xmin > 0 && xmin < 0.2)
+	    {
+		params_fit[1] = 2 * params_fit[0] * xmin / y_at_xmin;
+	    }
+	    else
+***/
+	    {
+	    	params_fit[1] = 1.1;
+	    }
 	}
 
 	return;
