@@ -724,7 +724,7 @@ void fill_ellipse_tk_handler(Tk_handler tk_handler, float x, float y, float rx,
 */
 
     XFillArc(tk_handler_p->display, tk_handler_p->drawable,
-                tk_handler_p->gc, xx-rx, yy-ry, 2*rxx, 2*ryy, 64*0, 64*360);
+                tk_handler_p->gc, xx-rxx, yy-ryy, 2*rxx, 2*ryy, 64*0, 64*360);
 }
 
 void draw_circle_tk_handler(Tk_handler tk_handler, float x, float y, float r)
@@ -746,7 +746,7 @@ void draw_ellipse_tk_handler(Tk_handler tk_handler, float x, float y, float rx,
 */
 
     XDrawArc(tk_handler_p->display, tk_handler_p->drawable,
-                tk_handler_p->gc, xx-rx, yy-ry, 2*rxx, 2*ryy, 64*0, 64*360);
+                tk_handler_p->gc, xx-rxx, yy-ryy, 2*rxx, 2*ryy, 64*0, 64*360);
 }
 
 void draw_polyline_tk_handler(Tk_handler tk_handler, Poly_line polyline)
