@@ -254,14 +254,14 @@ def make_struct_dict_from_polymer(polymer):
 
 def export_structure(mol_system, polymer, model_number):
 
-  from ccpnmr.analysis.core.StructureBasic import makeStructures
+  from ccpnmr.analysis.core.StructureIo import makeStructureEnsemble
 
   struct_dict = make_struct_dict_from_polymer(polymer)
 
   struct_dict = {model_number: struct_dict}
 
   try:
-    structure = makeStructures(struct_dict, mol_system) #, doWarnings=False)
+    structure = makeStructureEnsemble(struct_dict, mol_system) #, doWarnings=False)
   except:
     print struct_dict
     raise
@@ -555,7 +555,7 @@ class CCPNReader:
     def convert_dihedral_restraint_list(self, constraint_list):
         
         import data
-        from ccpnmr.analysis.MoleculeBasic import getAtomsTorsion
+        from ccp.lib.MoleculeQuery import getAtomsTorsion
 
         restraints = []
 
@@ -646,7 +646,7 @@ class CCPNReader:
     def convert_jcoupling_restraint_list(self, constraint_list):
         
         import data
-        from ccpnmr.analysis.MoleculeBasic import getAtomsTorsion
+        from ccp.lib.MoleculeQuery import getAtomsTorsion
         from ccpnmr.analysis.ConstraintBasic import getConstraintAtoms
 
         restraints = []
@@ -1139,7 +1139,7 @@ class CCPNReader:
 
     def export_ensemble(self, mol_system_name, ensemble, index_list, polymer):
 
-        from ccpnmr.analysis.core.StructureBasic import makeStructures
+        from ccpnmr.analysis.core.StructureIo import makeStructureEnsemble
 
         ## get molSystem
 
@@ -1180,7 +1180,7 @@ class CCPNReader:
 
             structures[i] = make_struct_dict_from_polymer(polymer)
             
-        ensemble = makeStructures(structures, mol_system)
+        ensemble = makeStructureEnsemble(structures, mol_system)
 
     def save(self):
       if self.debug:
