@@ -255,7 +255,7 @@ class NmrStarSequenceFile(NmrStarGenericFile):
             
             bondType = tableTags['Type'][i]
             # TODO currently not handled!
-            bondOrder = tableTags['Order'][i]
+            ###bondOrder = tableTags['Order'][i]
             
             sequenceElementData = []
             
