@@ -183,8 +183,12 @@ def findChemAtomOrSetSysName(namingSystem, chemAtomOrSet, warnAtomId=None,
     # Now try IUPAC instead
     
     if warnAtomId:
-      print ("  Warning: no %s atomSysName available for '%s', trying IUPAC." 
-             % (namingSystem.name, warnAtomId))
+      if namingSystem:
+        print ("  Warning: no %s atomSysName available for '%s', trying IUPAC."
+               % (namingSystem.name, warnAtomId))
+      else:
+        print ("  Warning: no namingSystem found for '%s', trying IUPAC."
+               % warnAtomId)
 
     ns = chemAtomOrSet.chemComp.findFirstNamingSystem(name='IUPAC')
     if ns:
@@ -2200,3 +2204,16 @@ def getChemAtomSetFromAtomSets(atomSets):
       return None
   else:
     return chemAtomSets.pop()
+
+
+def integerStringSortKey(key):
+  """return sort key so that strings starting with an integer sort as if by integer"""
+
+  result = list(key)
+  for ii,val in enumerate(result):
+    if isinstance(val, str):
+      vv = val.strip()
+      if vv and vv.isdigit():
+        result[ii] = '%30s' % vv
+
+  return result
