@@ -151,10 +151,12 @@ class DataLocationFrame(Frame):
  
         if relPathNew != relPath:
           # No notifiers for temporarily invalid path
-          dataUrl = dataStore.dataUrl
+          ###dataUrl = dataStore.dataUrl
           self.project.__dict__['override'] = True
-          for dataUrlStore in dataUrl.dataStores:
-            dataUrlStore.path = converseSplitPath(dataUrlStore.path)[1]
+          # 22 Aug 2014: the below completely messes up the other dataStores
+          ###for dataUrlStore in dataUrl.dataStores:
+          ###  dataUrlStore.path = converseSplitPath(dataUrlStore.path)[1]
+          dataStore.path = relPathNew
           self.project.__dict__['override'] = False
           changeDataStoreUrl(dataStore, absPathNew)
       
@@ -173,10 +175,13 @@ class DataLocationFrame(Frame):
  
         if relPathNew != relPath:
           # No notifiers for temporarily invalid path
-          dataUrl = dataStore.dataUrl
+          ###dataUrl = dataStore.dataUrl
           self.project.__dict__['override'] = True
-          for dataUrlStore in dataUrl.dataStores:
-            dataUrlStore.path = joinPath(absPaths[1], dataUrlStore.path)
+          # 22 Aug 2014: the below completely messes up the other dataStores
+          # everything is handled in changeDataStoreUrl so only need to change dataStore
+          ###for dataUrlStore in dataUrl.dataStores:
+          ###  dataUrlStore.path = joinPath(absPaths[1], dataUrlStore.path)
+          dataStore.path = relPathNew
           self.project.__dict__['override'] = False
           changeDataStoreUrl(dataStore, absPathNew)
   
