@@ -40,6 +40,11 @@ Development of a Software Pipeline. Proteins 59, 687 - 696.
 """
 import re
 
+try:
+  from memops.gui.MessageReporter import showWarning
+except:
+  from memops.universal.MessageReporter import showWarning
+
 from ccp.general.ChemCompOverview import chemCompStdDict
 from ccp.util.LabeledMolecule import getIsotopomerSingleAtomFractions, getIsotopomerAtomPairFractions
 from ccp.util.LabeledMolecule import singleAtomFractions, atomPairFractions
@@ -60,7 +65,7 @@ userResidueCodesDict = {DNA_MOLTYPE:{'A':'Ade','T':'Thy','G':'Gua','C':'Cyt','U'
                         CARBOHYDRATE_MOLTYPE:{}
                         }
 
-STANDARD_ISOTOPES = ['1H','13C','15N','31P','2H','29Si','19F','17O']
+STANDARD_ISOTOPES = ['1H','13C','14N','15N','31P','2H','29Si','19F','17O']
 
 DEFAULT_ISOTOPES = {'H':'1H','C':'13C','N':'15N','P':'31P','Si':'29Si',
                     'F':'19F','O':'16O'}
