@@ -177,8 +177,8 @@ def getExperimentAtomPairFractions(experiment, atom1, atom2):
         break
   
   else:
-    fractionDict1 = getMixtureAtomFractions(experiment, atom1)
-    fractionDict2 = getMixtureAtomFractions(experiment, atom2)
+    fractionDict1 = getExperimentAtomFractions(experiment, atom1)
+    fractionDict2 = getExperimentAtomFractions(experiment, atom2)
     
     for isotope1 in fractionDict1.keys():
       fraction1 = fractionDict1[isotope1]
