@@ -246,7 +246,8 @@ class Analysis:
         project.currentAnalysisProject = analysisProjects[0]
       else:
         # this automatically sets project.currentAnalysisProject
-        project.newAnalysisProject(name=project.name, nmrProject=project.currentNmrProject)
+        analysisProject = project.newAnalysisProject(name=project.name, nmrProject=project.currentNmrProject)
+        analysisProject.maxMarks = analysisProject.maxRulers = 10
 
     if not project.currentAnalysisProfile:
       analysisProfiles = project.sortedAnalysisProfiles()
