@@ -48,7 +48,10 @@ from ccpnmr.analysis.core.PeakBasic import findPeaks, searchPeaks, pickPeak
 from ccpnmr.analysis.core.UnitConverter import ppm2pnt, pnt2ppm
 from ccpnmr.analysis.core.Util import getAnalysisDataDim
 
-from memops.gui.MessageReporter import showWarning
+try:
+  from memops.gui.MessageReporter import showWarning
+except ImportError:
+  from memops.universal.MessageReporter import showWarning
 
 from math import sqrt
 
