@@ -44,7 +44,7 @@ import os
 import random, re
 
 from memops.universal.Io import joinPath
-from memops.universal.Util import isBigEndian
+from memops.universal.Util import isBigEndian, cumulativeProductArray
 from memops.universal.BlockData import determineBlockSizes, writeBlockData, cumulativeArray, arrayOfIndex
 
 from memops.general.Implementation import ApiError
@@ -62,6 +62,13 @@ from ccp.util.Spectrum import createBlockedMatrix
 from ccpnmr.analysis.core.Reference import getReference
 from ccpnmr.analysis.core.UnitConverter import unit_converter
 
+from ccp.lib.nmr.Nmr.DataSource import getIsotopeCodesList as getSpectrumIsotopes
+from ccp.lib.nmr.Nmr.DataSource import getOnebondDataDims
+from ccp.lib.nmr.Nmr.Experiment import getAcqExpDim, getOnebondExpDimRefs
+from ccp.lib.nmr.Nmr.AbstractDataDim import getIsotopeCodes as getDataDimIsotopes
+
+
+
 filterExpr1 = re.compile('\[[^A-Z]+\]')
 filterExpr2 = re.compile('H\([0123]\)')
 
@@ -74,11 +81,81 @@ COMMON_REF_EXPTS = set(['H', 'C', 'N', 'F', 'P','H[N]', 'H[C]', 'H[N[CO]]',
                         'H[C]_H.through-space','H[N[ca[HA]]]', 'H{[N]+[HA]}',
                         'H[C]_H[C].through-space','H[N]_H[C].through-space',
                         'H[N]_H[N].through-space','H[N]_H.relayed','H_H[N].relayed',
-                        'H_H.COSY','H_H.DQF-COSY','H_H.through-space','H_H.relayed',
+                        'HH','H_H.through-space','H_H.relayed',
                         'HC_CH.relayed','HC_cH.relayed','Hc_CH.relayed',
                         'H_H.ROESY', 'CC',
                         ])
 
+
+def selectPreferredRefExperiment(refExperiments, experiment=None):
+  """
+  Select preferred RefExperiment for experiment type from input list
+
+  .. describe:: Input
+  
+  List of ccp.nmr.NmrExpPrototype.RefExperiment
+  
+  ccp.nmr.Nmr.Experiment   # Currently not used
+  
+  .. describe:: Output
+
+  ccp.nmr.NmrExpPrototype.RefExperiment
+  """
+  
+  if not refExperiments:
+    return None
+  
+  # Narrow down to common ref experiments, if any
+  commonExps = [x for x in refExperiments if x.name in COMMON_REF_EXPTS]
+  if commonExps:
+    refExperiments = commonExps
+  
+  # return single candidate
+  if len(refExperiments) == 1:
+    return refExperiments[0]
+  
+  # Narrow down to simplest experiments (fewest atoms in transfer pathway)
+  dd = {}
+  for refExp in refExperiments:
+    nAtom = len(refExp.nmrExpPrototype.atomSites)
+    ll = dd.get(nAtom)
+    if ll:
+      ll.append(refExp)
+    else:
+      dd[nAtom]= [refExp]
+  nAtoms = sorted(dd.keys())
+  refExperiments = dd[nAtoms[0]]
+  
+  # remove multiple refExperiments from same prototype
+  foundPrototypes = {}
+  for refExp in refExperiments:
+    prototype = refExp.nmrExpPrototype
+    lastSerial = foundPrototypes.get(prototype)
+    newSerial = refExp.serial
+    if lastSerial is None or lastSerial > newSerial:
+      foundPrototypes[prototype] = newSerial
+  #
+  refExperiments = [prot.findFirstRefExperiment(serial=ser) 
+                    for (prot,ser) in foundPrototypes.items()]
+      
+  # return single candidate
+  if len(refExperiments) == 1:
+    return refExperiments[0]
+  
+  else:
+    # do not guess
+    return None
+  
+  # select alphabetically first name, for predictability
+  #dd = {}
+  #for refExp in refExperiments:
+  #  dd[refExp.name] = refExp
+  #for name,refExp in sorted(dd.items()):
+  #  break
+  #
+  #return refExp
+  
+
 def getRefExperimentCategories(refExperiment):
   """
   Get a set of categories (as strings) that a reference experiment
@@ -385,11 +462,11 @@ def getSampledDimExperiments(nmrProject):
 def getOnebondExpDimRefs(experiment):
   """
   Get pairs of experiment dimensions that are connected by onebond transfers
-  
+
   .. describe:: Input
-  
+
   Nmr.Experiment
-  
+
   .. describe:: Output
 
   List of 2-List of Nmr.ExpDimRefs
@@ -397,16 +474,15 @@ def getOnebondExpDimRefs(experiment):
 
   expDimRefs   = []
   expTransfers = []
-  
+
   for expTransfer in experiment.sortedExpTransfers():
     if expTransfer.transferType in ('onebond',):
       expTransfers.append(expTransfer)
-  
+
   for expTransfer in expTransfers:
     expDimRefs.append(expTransfer.sortedExpDimRefs())
-  
-  return expDimRefs
 
+  return expDimRefs
 
 def getEquivalentDataDims(spectrum):
   """
@@ -437,22 +513,21 @@ def getEquivalentDataDims(spectrum):
       if isotopeB and (isotopeB == isotopeA):
         dimPairs.append([dataDimA, dataDimB])
         
-  return dimPairs       
-       
-
+  return dimPairs 
+  
 def getOnebondDataDims(spectrum):
   """
   Get pairs of spectrum data dimensions that are connected by onebond transfers
-  
+
   .. describe:: Input
-  
+
   Nmr.DataSource
-  
+
   .. describe:: Output
 
   List of 2-List of Nmr.DataDims
   """
-  
+
   dataDims = []
   expDimRefs = getOnebondExpDimRefs(spectrum.experiment)
 
@@ -464,7 +539,7 @@ def getOnebondDataDims(spectrum):
       dataDims.append( [dataDim0,dataDim1] )
 
   return dataDims
-  
+
 def getDiagonalBondedDataDims(spectrum):
   """
   Get pairs of spectrum data dimensions that have digaonal positions
@@ -978,28 +1053,29 @@ def getCompatibleHsqcPeakLists(peakList, excludeSimulated=True):
 
   return peakLists
 
+'''
 def getAcqExpDim(experiment):
   """
   ExpDim that corresponds to acquisition dimension. NB uses heuristics
 
   .. describe:: Input
-  
+
    NmrExpPrototype.Experiment
-  
+
   .. describe:: Output
-  
+
   NmrExpPrototype.ExpDim
   """
-  
+
   ll = experiment.findAllExpDims(isAcquisition=True)
   if len(ll) == 1:
     # acquisition dimension set - return it
     result = ll.pop()
-  
+
   else:
     # no reliable acquisition dimension set
     result = None
-    
+
     dataSources = experiment.sortedDataSources()
     if dataSources:
       dataSource = dataSources[0]
@@ -1007,7 +1083,7 @@ def getAcqExpDim(experiment):
         # more than one data source. Pick one of the largest.
         if ds.numDim > dataSource.numDim:
           dataSource = ds
-      
+
       # Take dimension with most points
       useDim = None
       currentVal = -1
@@ -1019,20 +1095,19 @@ def getAcqExpDim(experiment):
         if val > currentVal:
           currentVal = val
           useDim = dd
-      
+
       if useDim is not None:
         result = useDim.expDim
-  
+
     if result is None:
       # no joy so far - just take first ExpDim
       ll = experiment.sortedExpDims()
       if ll:
         result = ll[0]
-      
+
   #
   return result
-      
-
+'''
 
 def getAcqRefExpDimRef(refExperiment):
   """
@@ -1110,7 +1185,7 @@ def setRefExperiment(experiment, refExperiment):
     return
   
   acqRefExpDim = getAcqRefExpDimRef(refExperiment).refExpDim
-  acqExpDim = getAcqExpDim(experiment)
+  acqExpDim = getAcqExpDim(experiment, ignorePreset=True)
   
   if ((refExpDims.index(acqRefExpDim)*2  < len(refExpDims)) !=
       (expDims.index(acqExpDim)*2  < len(expDims))):
@@ -1119,6 +1194,10 @@ def setRefExperiment(experiment, refExperiment):
     # dimensions will more likely get mapped to each other.
     refExpDims.reverse()
   
+  # Rasmus 12/7/12. Must be set to None, as otherwise it is never reset below.
+  # We do not want the heuristic getAcqExpDim to override everything else.
+  acqExpDim = None
+  
   for expDim in expDims:
     expData = []
     
@@ -1191,7 +1270,8 @@ def setRefExperiment(experiment, refExperiment):
             del inData[ii]
             del refData[jj]
             break
-        
+            
+  
 def getPossibleRefExperiments(experiment, category=None):
   """
   Get the possible reference NMR experiments for an experiment,
@@ -1327,8 +1407,8 @@ def getFilteredRefExperiments(experiment, category=None):
       for refExpDim in refExperiment.refExpDims:
         dimIsotopes = []
         for refExpDimRef in refExpDim.refExpDimRefs:
-	  expMeasurement = refExpDimRef.expMeasurement
-	  if expMeasurement.measurementType in ('Shift','shift','MQShift'):
+          expMeasurement = refExpDimRef.expMeasurement
+          if expMeasurement.measurementType in ('Shift','shift','MQShift'):
             iCodes = [ass.isotopeCode for ass in expMeasurement.atomSites]
             dimIsotopes.append(' '.join(sorted(iCodes)))
         dimIsotopes.sort()
@@ -1979,15 +2059,15 @@ def getSpectraByType(project, experimentType):
             spectra.append(dataSource)
       
   return spectra
-
+ 
 def getSpectrumIsotopes(dataSource):
   """
   Give isotopes pertianing to the dimensions of a given NMR spectrum 
-  
+
   .. describe:: Input
-  
+
   Nmr.DataSource
-  
+
   .. describe:: Output
 
   List of Words (Nmr.ExpDimRef.IsotopeCodes)
@@ -1997,9 +2077,9 @@ def getSpectrumIsotopes(dataSource):
   for dataDim in dataSource.sortedDataDims():
     isotopeCodes = list(getDataDimIsotopes(dataDim))
     isotopes.append(','.join(isotopeCodes) or None)
-  
+
   return isotopes
- 
+
 def findSpectrumDimsByIsotope(dataSource, isotopeCode):
   """
   Give dimension numbers of a spectrum that pertain to a given Isotope
@@ -2022,31 +2102,30 @@ def findSpectrumDimsByIsotope(dataSource, isotopeCode):
     if isotopeCode in isotopes:
       dims.append(i)
     
-  return dims    
-
+  return dims 
+  
 def getDataDimIsotopes(dataDim):
   """
   Get the shift measurement isotopes for a spectrum data dim
-  
+
   .. describe:: Input
-  
+
   Nmr.FreqDataDim
-  
+
   .. describe:: Output
 
   Set of Words (Nmr.ExpDimRef.isotopeCodes)
   """
 
   isotopes = set()
-    
+
   for expDimRef in dataDim.expDim.expDimRefs:
     if expDimRef.measurementType in ('Shift','shift'):
       for isotopeCode in expDimRef.isotopeCodes:
         isotopes.add(isotopeCode)
- 
+
   return isotopes
-  
-  
+
 def getNdSpectra(project, n):
   """
   Give all NMR spectra in a given project that have n dimensions
@@ -2452,20 +2531,12 @@ def isReferencingIncorrect(spectrum, fixErrors=False, printChecks=True):
   #
   return result
 
-def _getDict(objectOld, keys):
-
-  dd = {}
-  for key in keys:
-    dd[key] = getattr(objectOld, key)
-
-  return dd
-
 def cloneExperiment(experimentOld, experimentNameNew, dataSourceNameNew=None, cloneDataFile=True):
 
   keys = ('date', 'details', 'nmrTubeType', 'numDim', 'numScans', 'sampleState',
           'sampleVolume', 'spinningAngle', 'spinningRate', 'volumeUnit',
           'refExperiment', 'shiftList')
-  dd = _getDict(experimentOld, keys)
+  dd = dict(((x,getattr(experimentOld,x)) for x in keys))
   dd['name'] = experimentNameNew
   experimentNew = experimentOld.nmrProject.newExperiment(**dd)
 
@@ -2477,7 +2548,7 @@ def cloneExperiment(experimentOld, experimentNameNew, dataSourceNameNew=None, cl
     expDimNew = experimentNew.findFirstExpDim(dim=expDimOld.dim)
     expDimMap[expDimOld] = expDimNew
     keys = ('isAcquisition', 'refExpDim')
-    dd = _getDict(expDimOld, keys)
+    dd = dict(((x,getattr(expDimOld,x)) for x in keys))
     for key in dd:
       setattr(expDimNew, key, dd[key])
 
@@ -2486,13 +2557,13 @@ def cloneExperiment(experimentOld, experimentNameNew, dataSourceNameNew=None, cl
               'isotopeCodes', 'maxAliasedFreq', 'measurementType', 'minAliasedFreq',
               'name', 'nominalRefValue', 'sf', 'unit', 'variableIncrFraction',
               'refExpDimRef')
-      dd = _getDict(expDimRefOld, keys)
+      dd = dict(((x,getattr(expDimRefOld,x)) for x in keys))
       expDimRefNew = expDimNew.newExpDimRef(**dd)
       expDimRefMap[expDimRefOld] = expDimRefNew
 
   for expTransferOld in experimentOld.expTransfers:
     keys = ('isDirect', 'mixingTime', 'transferSubType', 'transferType')
-    dd = _getDict(expTransferOld, keys)
+    dd = dict(((x,getattr(expTransferOld,x)) for x in keys))
     dd['expDimRefs'] = [expDimRefMap[expDimRefOld] for expDimRefOld in expTransferOld.sortedExpDimRefs()]
     expTransferNew = experimentNew.newExpTransfer(**dd)
         
@@ -2500,13 +2571,13 @@ def cloneExperiment(experimentOld, experimentNameNew, dataSourceNameNew=None, cl
 
   keys = ('dataType', 'details', 'isSimulated', 'noiseLevel', 'numDim',
           'numShapes', 'numSparsePoints', 'recordNumber', 'scale',
-          'signalLevel', 'refSpectra', 'snMethod')
+          'signalLevel', 'refNmrSpectra', 'snMethod')
   if dataSourceNameNew is None:
     keys += ('name',)
   if cloneDataFile:
     keys += ('isNormalStorage', 'storageDetails',
              'compressMethod', 'dataStore', 'processMethod')
-  dd = _getDict(dataSourceOld, keys)
+  dd = dict(((x,getattr(dataSourceOld,x)) for x in keys))
   if dataSourceNameNew is not None:
     dd['name'] = dataSourceNameNew
 
@@ -2514,30 +2585,30 @@ def cloneExperiment(experimentOld, experimentNameNew, dataSourceNameNew=None, cl
 
   for dataDimOld in dataSourceOld.sortedDataDims():
     keys = ('dim', 'fileDim', 'isComplex', 'numPoints', 'shapeSerial', 'unit')
-    dd = _getDict(dataDimOld, keys)
+    dd = dict(((x,getattr(dataDimOld,x)) for x in keys))
     expDimOld = dataDimOld.expDim
     dd['expDim'] = expDimMap[expDimOld]
     if dataDimOld.className == 'FidDataDim':
       keys = ('alternateSign', 'firstValue', 'negateImaginary',
               'numPointsValid', 'oversamplingInfo', 'phase0', 'phase1',
               'pointOffset', 'valuePerPoint')
-      dd.update(_getDict(dataDimOld, keys))
+      dd.update(((x,getattr(dataDimOld,x)) for x in keys))
       dataDimNew = dataSourceNew.newFidDataDim(**dd)
     elif dataDimOld.className == 'FreqDataDim':
       keys = ('numPointsOrig', 'phase0', 'phase1',
               'pointOffset', 'valuePerPoint', 'predictMethod')
-      dd.update(_getDict(dataDimOld, keys))
+      dd.update(((x,getattr(dataDimOld,x)) for x in keys))
       dataDimNew = dataSourceNew.newFreqDataDim(**dd)
 
       keys = ('localValuePerPoint', 'refPoint', 'refValue')
       dataDimRefOld = getPrimaryDataDimRef(dataDimOld)
       expDimRefOld = dataDimRefOld.expDimRef
-      dd = _getDict(dataDimRefOld, keys)
+      dd = dict(((x,getattr(dataDimRefOld,x)) for x in keys))
       dd['expDimRef'] = expDimRefMap[expDimRefOld]
       dataDimRefNew = dataDimNew.newDataDimRef(**dd)
     elif dataDimOld.className == 'SampledDataDim':
       keys = ('conditionVaried', 'details', 'pointErrors', 'pointValues')
-      dd.update(_getDict(dataDimOld, keys))
+      dd.update(((x,getattr(dataDimOld,x)) for x in keys))
       dataDimNew = dataSourceNew.newSampledDataDim(**dd)
 
   return experimentNew
@@ -2615,3 +2686,75 @@ def defaultExperiment(nmrProject, experimentName, isotopeCodes, dataSourceName=N
 
   return experiment
 
+def _calcStats(block_file, first, last):
+
+  values = block_file.getValues(first, last)
+  n = len(values)
+  s = sum(values)
+  s2 = sum([v*v for v in values])
+
+  return n, s, s2
+
+def getRegionStats(spectrum, region):
+
+  from ccpnmr.analysis.core.PeakBasic import findDataDimRegions
+  from ccpnmr.analysis.core.Util import getAnalysisSpectrum
+
+  block_file = spectrum.block_file
+
+  if not block_file:
+    return []
+
+  analysisSpectrum = getAnalysisSpectrum(spectrum)
+  analysisProject = analysisSpectrum.analysisProject
+  axisUnit = analysisProject.findFirstAxisUnit(unit='ppm')
+
+  ndim = spectrum.numDim
+
+  if len(region) != ndim:
+    raise Exception('should have ndim (= %s) = len(region) (= %s)' % (ndim, len(region)))
+
+  regions = ndim * [0]
+  dataDims = spectrum.sortedDataDims()
+  rdim = 0
+  for dataDim in dataDims:
+    dim = dataDim.dim - 1
+    if dataDim.className == 'FreqDataDim':
+      (r0, r1) = ppmDataDimBoundedRegion(region[rdim], dataDim)
+      rdim += 1
+
+      (regions[dim], min_point, max_point) = \
+           findDataDimRegions(dataDim, (r0, r1), axisUnit, thickness=0, addOneToUpperPoint=False)
+    else:
+      npoints = dataDim.numPoints
+      (r0, r1) = region[rdim]
+      r0 = int(r0-1)
+      r1 = int(r1)
+      rdim += 1
+      regions[dim] = [(r0, r1)]
+
+  ntotal = stotal = s2total = 0
+  first = ndim * [0]
+  last = ndim * [0]
+  (nregions, cumulative) = cumulativeProductArray([len(reg) for reg in regions])
+  for r in range(nregions):
+    a = arrayOfIndex(r, cumulative)
+    reg = [ regions[i][a[i]] for i in range(len(a)) ]
+    for dataDim in spectrum.dataDims:
+      dim = dataDim.dim - 1
+      first[dim] = int(reg[dim][0])
+      last[dim] = int(reg[dim][1])
+
+    n, s, s2 = _calcStats(block_file, first, last)
+    ntotal += n
+    stotal += s
+    s2total += s2
+
+  if ntotal > 0:
+    avg = stotal / float(ntotal)
+    s2total /= float(ntotal)
+    std = math.sqrt(s2total - avg*avg)
+  else:
+    avg = std = 0
+
+  return ntotal, avg, std
