@@ -402,7 +402,7 @@ def setWindowPeakListState(winPeakList, state):
 
 def toggleSpectrum(window, shortcut=None, spectrum=None, isGlobal=False):
   """
-  Toggle whether a spectrum is diaplayed in a spectrum window.
+  Toggle whether a spectrum is displayed in a spectrum window.
   
   .. describe:: Input
   
@@ -470,6 +470,120 @@ def toggleSpectrum(window, shortcut=None, spectrum=None, isGlobal=False):
 
   return spectrum
 
+def toggleWindowSpectra(window, isGlobal=False):
+  """
+  Turn all spectra off in a spectrum window (all windows if isGlobal is True)
+  if any on (in that window) or all spectra on if all of them are off.
+  
+  .. describe:: Input
+  
+  Analysis.SpectrumWindow, Boolean
+  
+  .. describe: Output
+  
+  None
+  """
+
+  views = []
+  for windowPane in window.spectrumWindowPanes:
+    views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+    views.extend(views2)
+  
+  state = True
+  for view in views:
+    if windowPaneHasValueAxis(view.spectrumWindowPane):
+      if view.isSliceVisible:
+        state = False
+        break
+    else:
+      if view.isPosVisible or view.isNegVisible:
+        state = False
+        break
+
+  if isGlobal:
+    for window2 in window.parent.spectrumWindows:
+      if window2 is not window:
+        for windowPane in window2.spectrumWindowPanes:
+          views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+          views.extend(views2)
+  
+  for view in views:
+    if windowPaneHasValueAxis(view.spectrumWindowPane):
+      view.isSliceVisible = state
+    else:
+      view.isPosVisible = view.isNegVisible = view.isSliceVisible = state
+ 
+    for winPeakList in view.windowPeakLists:
+      winPeakList.isSymbolDrawn = winPeakList.isAnnotationDrawn = state
+ 
+def turnWindowSpectraOn(window, isGlobal=False):
+  """
+  Turn all spectra on in a spectrum window (all windows if isGlobal is True).
+  
+  .. describe:: Input
+  
+  Analysis.SpectrumWindow, Boolean
+  
+  .. describe: Output
+  
+  None
+  """
+
+  views = []
+  for windowPane in window.spectrumWindowPanes:
+    views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+    views.extend(views2)
+  
+  if isGlobal:
+    for window2 in window.parent.spectrumWindows:
+      if window2 is not window:
+        for windowPane in window2.spectrumWindowPanes:
+          views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+          views.extend(views2)
+  
+  for view in views:
+    if windowPaneHasValueAxis(view.spectrumWindowPane):
+      view.isSliceVisible = True
+    else:
+      view.isPosVisible = view.isNegVisible = view.isSliceVisible = True
+ 
+    for winPeakList in view.windowPeakLists:
+      winPeakList.isSymbolDrawn = winPeakList.isAnnotationDrawn = True
+ 
+def turnWindowSpectraOff(window, isGlobal=False):
+  """
+  Turn all spectra off in a spectrum window (all windows if isGlobal is True).
+  
+  .. describe:: Input
+  
+  Analysis.SpectrumWindow, Boolean
+  
+  .. describe: Output
+  
+  None
+  """
+
+  views = []
+  for windowPane in window.spectrumWindowPanes:
+    views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+    views.extend(views2)
+  
+  if isGlobal:
+    for window2 in window.parent.spectrumWindows:
+      if window2 is not window:
+        for windowPane in window2.spectrumWindowPanes:
+          views2 = [view for view in windowPane.spectrumWindowViews if view.isInToolbar]
+          views.extend(views2)
+  
+  for view in views:
+    if windowPaneHasValueAxis(view.spectrumWindowPane):
+      view.isSliceVisible = False
+    else:
+      view.isPosVisible = view.isNegVisible = view.isSliceVisible = False
+ 
+    for winPeakList in view.windowPeakLists:
+      winPeakList.isSymbolDrawn = winPeakList.isAnnotationDrawn = False
+ 
 def getSpectrumWindowView(windowPane, spectrum):
   """
   Get the SpectrumWindowView object for a given spectrum in a
@@ -1889,6 +2003,60 @@ def calculateNoise(argServer=None, canvas=None):
   if windowFrame and canvas:
     windowFrame.calculateNoise(canvas)
 
+def toggleSpectra(argServer=None):
+  """
+  Turn all spectrum in window off (if any on) or on (if all off)
+  
+  .. describe:: Input
+  
+  ArgumentServer
+  
+  .. describe: Output
+  
+  None
+  """
+
+  windowPane = argServer.getCurrentWindowPane()
+
+  if windowPane:
+    toggleWindowSpectra(windowPane.spectrumWindow)
+
+def turnSpectraOn(argServer=None):
+  """
+  Turn all spectrum in window on
+  
+  .. describe:: Input
+  
+  ArgumentServer
+  
+  .. describe: Output
+  
+  None
+  """
+
+  windowPane = argServer.getCurrentWindowPane()
+
+  if windowPane:
+    turnWindowSpectraOn(windowPane.spectrumWindow)
+
+def turnSpectraOff(argServer=None):
+  """
+  Turn all spectrum in window off
+  
+  .. describe:: Input
+  
+  ArgumentServer
+  
+  .. describe: Output
+  
+  None
+  """
+
+  windowPane = argServer.getCurrentWindowPane()
+
+  if windowPane:
+    turnWindowSpectraOff(windowPane.spectrumWindow)
+
 def initWindowMacros(project):
   """
   Initialise window macros, adding default ones that not already included
@@ -1956,6 +2124,9 @@ def initWindowMacros(project):
          ('endPositionDelta',      'D'),
          ('resetWindowSliceRange', 'z'),
          ('calculateNoise',        'N'),
+         ('toggleSpectra',         't'),
+         ('turnSpectraOn',         'f'),
+         ('turnSpectraOff',        'g'),
        ):
 
     if function not in functions:
