@@ -558,10 +558,14 @@ class WindowDraw:
   def findNearbyPeak(self, peakList, region, xdim, ydim, xscale, yscale):
 
     if not (hasattr(peakList, 'cPeakList') and peakList.cPeakList):
-      return
+      return None
 
-    first = [ r[0] for r in region ]
-    last  = [ r[1] for r in region ]
+    try:
+      first = [ r[0] for r in region ]
+      last  = [ r[1] for r in region ]
+    except:
+      # this can happen if region not set up correctly
+      return None
     
     #print 'findNearbyPeak', self.windowPane.name, xdim, ydim, xscale, yscale, first, last
     allow_aliasing = getDimWrapped(peakList.dataSource)
@@ -1045,12 +1049,13 @@ class WindowDraw:
       xFromUnit = xaxisPanel.axisUnit.unit
       yFromUnit = yaxisPanel.axisUnit.unit
     elif drawMethod == peak_draw_methods[4]: # line width
-      px = py = 1.0
+      px = py = 2.0 # changed from 1.0 on 7 Oct 2014 because was showing double line width
       xFromUnit = yFromUnit = 'point'
       toUnit = 'Hz'
     elif drawMethod == peak_draw_methods[5]: # box width
-      px = getPeakFindBoxwidth(xDataDim)
-      py = getPeakFindBoxwidth(yDataDim)
+      # added 0.5 factor on 7 Oct 2014 because was showing double box width
+      px = 0.5 * getPeakFindBoxwidth(xDataDim) if xDataDim else 1.0
+      py = 0.5 * getPeakFindBoxwidth(yDataDim) if yDataDim else 1.0
       xFromUnit = yFromUnit = 'point'
     else:
       (r0, r1) = xAxisRegion.region
@@ -1097,6 +1102,12 @@ class WindowDraw:
     if not view.axisMappings:
       return True
 
+    for label in ('x', 'y'): # should not need this check but seem to get exceptions when axisMapping is None in y
+      if self.hasValueAxis and label == 'y':
+        continue
+      if not view.findFirstAxisMapping(label=label):
+        return True
+
     if len(view.axisMappings) != view.analysisSpectrum.dataSource.numDim:
       return True
 
@@ -1611,7 +1622,9 @@ class WindowDraw:
     for axisPanel in self.windowPane.sortedAxisPanels()[2:]:
       axisType = axisPanel.axisType
       if axisType and not axisType.isSampled:
-        region = axisPanel.sortedAxisRegions()[strip].region
+        #region = axisPanel.sortedAxisRegions()[strip].region
+        axisRegion = axisPanel.sortedAxisRegions()[strip]
+        region = getAxisRegionRegion(axisRegion)
         midpoint = 0.5 * (region[0] + region[1])
         text = formatDecimals(midpoint, decimals=axisType.numDecimals)
         texts.append(text)
