@@ -69,12 +69,16 @@ class RowObject:
 
 class NoeDistParamsFrame(Frame):
 
-  def __init__(self, parent, nmrProject, peakList=None, *args, **kw):
+  def __init__(self, parent, nmrProject, peakList=None,
+               intensityTypeCallback=None, distanceFunctionCallback=None,
+               *args, **kw):
 
     self.nmrProject = nmrProject
     self.peakList = peakList
     self.analysisPeakList = None
     self.parent = parent
+    self.intensityTypeCallback = intensityTypeCallback
+    self.distanceFunctionCallback = distanceFunctionCallback
 
     Frame.__init__(self, parent=parent, **kw)
     self.grid_rowconfigure(1, weight=1)
@@ -213,6 +217,9 @@ class NoeDistParamsFrame(Frame):
         
       self.update(self.peakList)
 
+      if self.distanceFunctionCallback:
+        self.distanceFunctionCallback(name)
+
   def changeIntensityType(self, intensityType):
  
     self.intensityType = intensityType
@@ -222,6 +229,9 @@ class NoeDistParamsFrame(Frame):
 
     self.updateBaseline()
 
+    if self.intensityTypeCallback:
+      self.intensityTypeCallback(intensityType)
+
   def updateIntensityTypes(self, *obj):
   
     if self.analysisPeakList:
