@@ -40,12 +40,13 @@ def setupCyanaCalculation(argServer):
                              )
 def setupCyanaCalculationDialogue(argServer):
 
-  intIo.setupSingleDialogue(argServer, protocolName='CYANA_SS4',
+  intIo.setupCyana2CcpnDialogue(argServer, protocolName='CYANA_SS4',
                              )
 def runCyana2CcpnDialogue(argServer):
 
-  intIo.runCyana2CcpnDialogue(argServer, protocolName='CYANA_SS4',
+  calculationData = intIo.runCyana2CcpnDialogue(argServer, protocolName='CYANA_SS4',
                              )
+  return calculationData
 
 def runPreviousCalculation(argServer):
 
@@ -55,9 +56,12 @@ def setupPreviousCalculation(argServer):
 
   intIo.setupPreviousCalculation(argServer, protocolName='CYANA_SS4')
 
-def importDataFromCyana(argServer):
-
-  intIo.importDataFromCyana(argServer)
+def importDataFromCyana(argServer, calculationData=None):
+  if calculationData == None:
+    dataSources = intIo.importDataFromCyana(argServer)
+  else:
+    dataSources = intIo.importDataFromCyana(calculationData)
+  return dataSources
 
 def runCyanaPeaklist(argServer):
 
