@@ -9,7 +9,7 @@ def calculateT2List(argServer):
     argServer.showWarning(msg )
     return
 
-  t1rhoList = argServer.getMeasurementList(className='T1rhoList')
+  t1rhoList = argServer.getMeasurementList(className='T1RhoList')
   
   if not t1rhoList:
     msg = 'Stopping: Script cancelled or no T1rho List available.'
