@@ -1691,8 +1691,11 @@ class BrowseConstraintsPopup(BasePopup):
         buttons[3].enable()
       else:  
         buttons[3].disable()
-        
-      constraint = self.item.constraint
+
+      if self.item.className == "ChemShiftConstraint":
+        constraint = self.item
+      else:
+        constraint = self.item.constraint
       
       if constraint.peaks:
         buttons[4].enable()
