@@ -651,14 +651,16 @@ class BrowseResonancesPopup(BasePopup):
     for carbonResonance in carbonResonances:
       (molSystem, chain, residue, name) = getResonanceAtomTuple(carbonResonance)
       protonResonances = getOnebondResonances(carbonResonance, isotopeCode='1H')
-      for protonResonance in protonResonances:
+      if len(protonResonances) > 0:
+        for protonResonance in protonResonances:
         # wb104: not sure why we need to do the below but Igor's macro did it
-        (molSystem1, chain1, residue1, name1) = getResonanceAtomTuple(protonResonance)
-        if name=='Cga' or name=='Cgb' or name=='Cda' or name=='Cdb':
-          if name[1:3]!=name1[1:3]:
-            continue
-        resonancePairs.append([carbonResonance,protonResonance])
-      
+        # (molSystem1, chain1, residue1, name1) = getResonanceAtomTuple(protonResonance)
+        # if name=='Cga' or name=='Cgb' or name=='Cda' or name=='Cdb':
+        #   if name[1:3]!=name1[1:3]:
+        #     continue
+          resonancePairs.append([carbonResonance,protonResonance])
+      else:
+        resonancePairs.append([carbonResonance])
     for windowPulldown in (self.windowRes1Pulldown, self.windowRes2Pulldown, self.windowRes3Pulldown):
       windowPane = windowPulldown.getObject()
       if windowPane:
@@ -716,7 +718,7 @@ class BrowseResonancesPopup(BasePopup):
         for isotope in panelType.axisType.isotopeCodes:
           if panelTypeDict.get(isotope) is None:
             panelTypeDict[isotope] = []
-        panelTypeDict[isotope].append(panelType)
+          panelTypeDict[isotope].append(panelType)
 
       panelTypes = panelTypeDict.get(shift.resonance.isotopeCode, [])
 
