@@ -371,7 +371,7 @@ class CalcRatesPopup(BasePopup):
     self.gradLengthEntry = FloatEntry(frame, text=None, tipText=tipText, grid=(0,3), width=8)
   
     tipText = 'The maximum gradient strength (i.e. at 100%); used if relative gradient strengths have been entered'
-    label = Label(frame, text='Full gradient stength (G/cm):', grid=(1,0))
+    label = Label(frame, text='Full gradient strength (G/cm):', grid=(1,0))
     self.gradStrengthEntry = FloatEntry(frame, text=None, tipText=tipText, grid=(1,1), width=8)
   
     tipText = 'The short time interval between bipolar gradients, if bipolar gradients were used'
@@ -871,6 +871,12 @@ class CalcRatesPopup(BasePopup):
         sampleConditionType = self.getExpSeriesCondition(expSeries)
         (xData,yData,xWidths,yWidths) = getPeakSeriesIntensities(peaks, expSeries, self.intensityType, sampleConditionType)
     
+    seriesType, unit = self.getExpSeriesType(self.expSeries)
+    if seriesType == GRADIENT_STRENGTH and unit == '%':
+      # wb104: 10 Mar 2014: convert to G/cm from %
+      gradStren = 0.01*(self.gradStrengthEntry.get() or 100.0)
+      xData = [gradStren*x for x in xData]
+    
     dataFitting.dataX   = xData  
     dataFitting.dataY   = yData  
     dataFitting.dataErr = errData  
@@ -954,12 +960,13 @@ class CalcRatesPopup(BasePopup):
         bipolSep = self.bipolarSepEntry.get() or 0.0
  
         if diffTime and gradLen:
-          if unit == '%':
-            q *= gradStren * 1e2 # Gauss per cm to Tesla per metre / 100
-            qError *= gradStren * 1e2
-          else:
-            q *= 1e4 # Gauss per cm to Tesla per metre
-            qError *= 1e4
+          # wb104: 10 Mar 2014: below if doesn't belong because have converted xData values before the fit
+          #if unit == '%':
+          #  q *= gradStren * 1e2 # Gauss per cm to Tesla per metre / 100
+          #  qError *= gradStren * 1e2
+          #else:
+          q *= 1e4 # Gauss per cm to Tesla per metre
+          qError *= 1e4
         
           f = diffTime - (gradLen/3.0) - (bipolSep/2.0)
 
@@ -1600,8 +1607,11 @@ class CalcRatesPopup(BasePopup):
    
     self.updateButtons()
     
-    if self.fitGraphPopup:
-      self.showFunctionFit(noOpen=True)
+    # wb104: 27 Mar 2014: below causes exception when switch between expSeries 
+    # (that exception only happens if the functionFit is open)
+    # this means that some graphs might need to be updated manually
+    #if self.fitGraphPopup:
+    #  self.showFunctionFit(noOpen=True)
 
     nDim = 2
     if self.peakList:
@@ -1661,7 +1671,10 @@ class CalcRatesPopup(BasePopup):
       errors = dataFitting.parameterErrors
        
       if dataFitting.fitFunction == 10:
+        # wb104: 10 Mar 2014: dangerous so take copy to play safe
+        params = params[:]
         params[1] = sqrt(params[1])
+        errors = errors[:]
         errors[1] = sqrt(errors[1]) # Only temporary!
       
       for j in range(nParams):
