@@ -164,6 +164,7 @@ class EditAssignmentPopup(BasePopup):
     self.contrib = None
     self.structure = None
     self.restrictMolSys = True
+    self.showMolSys = False
     self.boundAtoms = True
     self.spectrumDict = {}
     self.aliasing = True
@@ -270,7 +271,12 @@ class EditAssignmentPopup(BasePopup):
     self.groupsSelect = CheckButton(frame, callback=self.toggleGroups,
                                     selected=False, grid=(1,5), tipText=tipText)
 
-    frame2 = Frame(frame, grid=(2,0), gridSpan=(1,6))
+    label = Label(frame, text='Show Mol System', grid=(2,0))
+    tipText = 'Whether to show molecular system in the proposed resonance table'
+    self.showMolSysSelect = CheckButton(frame, callback=self.setShowMolSys,
+                                        selected=False, grid=(2,1), tipText=tipText)
+
+    frame2 = Frame(frame, grid=(3,0), gridSpan=(1,6))
     frame2.expandGrid(1,4)
     
     label = Label(frame2, text='Isotope Labelling:', grid=(0,0))
@@ -917,6 +923,30 @@ class EditAssignmentPopup(BasePopup):
       
       self.updateAfter()
 
+  def haveCommonPeakContrib(self, resonance1, resonance2):
+    
+    peakDimContribs1 = resonance1.peakDimContribs
+    if not peakDimContribs1:
+      return True # not sure if this is correct
+
+    peakDimContribs2 = resonance2.peakDimContribs
+    if not peakDimContribs2:
+      return True # not sure if this is correct
+      
+    peakContribs1 = set()
+    for peakDimContrib in peakDimContribs1:
+      peakContribs1 |= peakDimContrib.peakContribs
+    if not peakContribs1:
+      return True # not sure if this is correct
+    
+    peakContribs2 = set()
+    for peakDimContrib in peakDimContribs2:
+      peakContribs2 |= peakDimContrib.peakContribs
+    if not peakContribs2:
+      return True # not sure if this is correct
+      
+    return peakContribs1 & peakContribs2
+
   def showStructConnections(self):
 
     if self.peak:
@@ -952,7 +982,7 @@ class EditAssignmentPopup(BasePopup):
         for r1 in resonances1:
           if r1:
             for r2 in resonances2:
-              if r2:
+              if r2 and self.haveCommonPeakContrib(r1, r2):
                 popup.showResonancesConnection(r1,r2)
 
       else:
@@ -987,6 +1017,14 @@ class EditAssignmentPopup(BasePopup):
     self.restrictMolSys = boolean
 
 
+  def setShowMolSys(self, boolean):
+  
+    if self.showMolSys != boolean:
+      self.updateAfter()
+    
+    self.showMolSys = boolean
+
+
   def setDoubleTolerance(self, boolean):
   
     if self.doubleTol != boolean:
@@ -1946,7 +1984,8 @@ class EditAssignmentPopup(BasePopup):
                                            component=component,
                                            resetScrollbars=resetScrollbars,
                                            molSystems=molSystems,
-                                           doubleTol=self.doubleTol)
+                                           doubleTol=self.doubleTol,
+                                           showMolSystem=self.showMolSys)
 
             self.mainCouplingButtons[i].grid(row=2*i+1, column=0, columnspan=1, sticky='nsew') 
             self.newResButtons[i].grid(row=2*i+1, column=1, columnspan=1, sticky='nsew')
@@ -1959,7 +1998,8 @@ class EditAssignmentPopup(BasePopup):
                                            component=component,
                                            noDisplay=noDisplay,
                                            molSystems=molSystems,
-                                           doubleTol=self.doubleTol)
+                                           doubleTol=self.doubleTol,
+                                           showMolSystem=self.showMolSys)
                                          
             peakDimsB.append(peakDim)
             componentsB.append(component)
@@ -2126,7 +2166,8 @@ class EditAssignmentPopup(BasePopup):
                                       resetScrollbars=resetScrollbars,
                                       molSystems=molSystems,
                                       component=componentsB[i],
-                                      doubleTol=self.doubleTol)
+                                      doubleTol=self.doubleTol,
+                                      showMolSystem=self.showMolSys)
        
     self.refresh = False
       
