@@ -389,6 +389,27 @@ class EditExperimentSeriesPopup(BasePopup):
     
         self.updateAfter()
     
+  def checkAddSampleCondition(self, experiment):
+
+    conditionSet = getExperimentConditionSet(experiment)
+    conditionName = self.expSeries.conditionNames[0]
+    condDict = getNmrExpSeriesSampleConditions(self.expSeries)
+
+    sampleConditions = condDict.get(conditionName, [])
+    units = [sc.unit for sc in sampleConditions if sc.unit]
+
+    if units:
+      sortList = list(set(units))
+      sortList.sort(key = lambda u:units.count(u))
+      unit = sortList[-1]
+    else:
+      unit = CONDITION_UNITS_DICT[conditionName][0]
+
+    condition = conditionSet.findFirstSampleCondition(condition=conditionName)
+    if not condition:
+      condition = conditionSet.newSampleCondition(condition=conditionName,
+                                                  unit=unit, value=0.0, error=0.0)
+                                                  
   def addConditionPoint(self):
   
     if self.expSeries and (self.expSeries.className != 'Experiment'):
@@ -403,25 +424,7 @@ class EditExperimentSeriesPopup(BasePopup):
       if experiment not in self.expSeries.experiments:
         self.expSeries.addExperiment(experiment)
       
-      conditionSet = getExperimentConditionSet(experiment)
-      conditionName = self.expSeries.conditionNames[0]
-      condDict = getNmrExpSeriesSampleConditions(self.expSeries)
-      
-      sampleConditions = condDict.get(conditionName, [])
-      units = [sc.unit for sc in sampleConditions if sc.unit]
-      
-      if units:
-        sortList = list(set(units))
-        sortList.sort(key = lambda u:units.count(u))
-        unit = sortList[-1]
-      else:
-        unit = CONDITION_UNITS_DICT[conditionName][0]
-      
-      condition = conditionSet.findFirstSampleCondition(condition=conditionName)
-      if not condition:
-        condition = conditionSet.newSampleCondition(condition=conditionName,
-                                                    unit=unit, value=0.0, error=0.0)
-
+      self.checkAddSampleCondition(experiment)
       self.updateAfter()
 
   def deleteConditionPoint(self, *event):
@@ -449,20 +452,24 @@ class EditExperimentSeriesPopup(BasePopup):
         self.conditionPoint = None
            
 
-
   def selectConditionPoint(self, object, row, col):
   
     if object:
       self.conditionPoint = object
       self.updateButtons()
 
-
   def selectExpSeries(self, object, row, col):
 
     if object:
       self.expSeries = object
+      self.checkExperimentConditionsConsistent()
       self.updateConditions()
 
+  def checkExperimentConditionsConsistent(self):
+
+    if self.expSeries.className != 'Experiment':
+      for experiment in self.expSeries.experiments:
+        self.checkAddSampleCondition(experiment)
 
   def getUnits(self):
   
