@@ -443,8 +443,9 @@ class EditFitGraphPopup(BasePopup):
       if not err:
         err = None
       
-      if self.method == 10:
-        x = [sqrt(v) for v in x]
+      # wb104: 10 Mar 2014: not sure why the below was here, it isn't needed
+      #if self.method == 10:
+      #  x = [sqrt(v) for v in x]
 
       data = [ (x[i],y[i],yFit[i],y[i]-yFit[i],dataFitting.objects[i], err and err[i]) for i in range(N) ]
       data.sort()
