@@ -268,7 +268,7 @@ class EditMeasurementListsPopup(BasePopup):
                  'setJCouplingList','setRdcList',
                  'setShiftAnisotropyList','setShiftDifferenceList',
                  'setShiftList','setT1List',
-                 'setT1rhoList','setT2List'):
+                 'setT1RhoList','setT2List'):
       for clazz in ('ccp.nmr.Nmr.Experiment',):
         notifyFunc(self.updateExperiments, clazz, func)
 
@@ -278,7 +278,7 @@ class EditMeasurementListsPopup(BasePopup):
                     'ccp.nmr.Nmr.JCouplingList', 'ccp.nmr.Nmr.RdcList',
                     'ccp.nmr.Nmr.ShiftAnisotropyList', 'ccp.nmr.Nmr.ShiftDifferenceList',
                     'ccp.nmr.Nmr.ShiftList', 'ccp.nmr.Nmr.T1List',
-                    'ccp.nmr.Nmr.T1rhoList', 'ccp.nmr.Nmr.T2List'):
+                    'ccp.nmr.Nmr.T1RhoList', 'ccp.nmr.Nmr.T2List'):
         notifyFunc(self.updateMeasurementListAfter, clazz, func)
  
     # Measurements
