@@ -890,8 +890,11 @@ class EditSpectrumPopup(BasePopup):
     spectra = []
     
     if self.nmrProject:
-      for experiment in self.nmrProject.sortedExperiments():
-        spectra += experiment.sortedDataSources()
+      #for experiment in self.nmrProject.sortedExperiments():
+      #  spectra += experiment.sortedDataSources()
+      experiments = sorted(self.nmrProject.experiments, key=lambda experiment: experiment.name)
+      for experiment in experiments:
+        spectra.extend(sorted(experiment.dataSources, key=lambda dataSource: dataSource.name))
     
     return spectra
 
