@@ -372,12 +372,21 @@ class EditWindowPopup(BasePopup):
     frameB.grid_columnconfigure(1, weight=1)
     
     row = 0
-    label = Label(frameB, text='Spectrum Window: ', grid=(row,0))
+    frame = Frame(frameB, grid=(row, 0))
+    
+    label = Label(frame, text='Spectrum Window: ', grid=(0,0))
 
     tipText = 'Selects the spectrum window to display the mappable spectra & peak lists for'
-    self.mapWindowPulldown = PulldownList(frameB, callback=self.changeMapWindow,
-                                          grid=(row,1), tipText=tipText)
+    self.mapWindowPulldown = PulldownList(frame, callback=self.changeMapWindow,
+                                          grid=(0,1), tipText=tipText)
 
+    texts = ('All On', 'All Off', 'Invert')
+    commands = (lambda: self.setAllSpectraVisibility(True), lambda: self.setAllSpectraVisibility(False), self.invertSpectraVisibility)
+    tipTexts = ('Turn on all spectra (contours, etc.) and peak lists for this window',
+                'Turn off all spectra (contours, etc.) and peak lists for this window',
+                'Invert visibility of spectra (contours, etc.) and peak lists for this window')
+    buttons = ButtonList(frameB, texts=texts, commands=commands, tipTexts=tipTexts, grid=(row, 1), sticky='e')
+    
     row += 1
     div = LabelDivider(frameB, text='Mapped Spectra', grid=(row,0), gridSpan=(1,2))
 
@@ -1256,6 +1265,31 @@ class EditWindowPopup(BasePopup):
     self.mapWindowPane = windowPane
     self.updateMappingsAfter()
 
+  def setAllSpectraVisibility(self, isVisible):
+    
+    windowPane = self.mapWindowPane
+    if not windowPane:
+      return
+      
+    for view in windowPane.spectrumWindowViews:
+      view.isNegVisible = view.isPosVisible = view.isSliceVisible = isVisible
+      for winPeakList in view.windowPeakLists:
+        winPeakList.isAnnotationDrawn = winPeakList.isSymbolDrawn = isVisible
+      
+  def invertSpectraVisibility(self):
+  
+    windowPane = self.mapWindowPane
+    if not windowPane:
+      return
+      
+    for view in windowPane.spectrumWindowViews:
+      view.isNegVisible = not view.isNegVisible
+      view.isPosVisible = not view.isPosVisible
+      view.isSliceVisible = not view.isSliceVisible
+      for winPeakList in view.windowPeakLists:
+        winPeakList.isAnnotationDrawn = not winPeakList.isAnnotationDrawn
+        winPeakList.isSymbolDrawn = not winPeakList.isSymbolDrawn
+    
   def updateMappingsAfter(self, *obj):
 
     if self.waitingM:
