@@ -173,8 +173,7 @@ def exportSeriesShifts(experimentSeries, sep=''):
 
   if sep == '':
     line = '!' + ' ' * 11
-    for resName in resNames:
-      line += ' ' * 5
+    line += ' ' * (5*maxResonances)
     
     for value, sc in conditions:
       line += '%15.15s' % ('%.3f' % value)
