@@ -581,7 +581,7 @@ class LinkPeakListsPopup(BasePopup):
         spectrum = view.analysisSpectrum.dataSource
         freqDims = [dd for dd in spectrum.dataDims if dd.className == 'FreqDataDim']
         
-        if len(freqDims) > 2:
+        if len(freqDims) >= 2:
           peakList = spectrum.activePeakList or spectrum.findFirstPeakList()
           
           if peakList:
