@@ -324,6 +324,8 @@ class NewWindowPopup(BasePopup):
                  isotopes.add(isotopeCode)
           
               dimTypes.append((expDimRef.measurementType.lower(), isotopes))
+          else:
+            dimTypes.append('sampled')
           
           spectrumIsotopes[spectrum].append(dimTypes)
     
@@ -348,10 +350,20 @@ class NewWindowPopup(BasePopup):
           continue  # value axis
         
         for i, dimTypes in enumerate(dimIsotopes):
-          for measurementType, isotopes in dimTypes:
-             if (mType == measurementType) and (selected <= isotopes):
-               dimIsotopes.pop(i)
-               break
+          for dimType in dimTypes:
+            if dimType == 'sampled':
+              if label != 'z1':
+                continue
+              axisType = self.axis_lists[label].getObject()
+              if axisType.name != 'sampled':
+                continue
+              dimIsotopes.pop(i)
+              break
+            else:
+              measurementType, isotopes = dimType
+              if (mType == measurementType) and (selected <= isotopes):
+                dimIsotopes.pop(i)
+                break
           else:
             continue
           break       
@@ -521,8 +533,11 @@ class NewWindowPopup(BasePopup):
   def getAxisTypes(self, label):
 
     axisTypes = self.parent.getAxisTypes()
-    axisTypes = filter(lambda x: not x.isSampled, axisTypes)
-    axisTypes = [ axisType for axisType in axisTypes if not axisType.isSampled ]
+
+    if label == 'z1':
+      axisTypes = [ axisType for axisType in axisTypes if axisType.name == 'sampled' or not axisType.isSampled ]
+    else:
+      axisTypes = [ axisType for axisType in axisTypes if not axisType.isSampled ]
     
     if label != 'y':
       axisTypes = [ at for at in axisTypes if at.name != WindowBasic.VALUE_AXIS_NAME ]
