@@ -483,8 +483,9 @@ class OpenSpectrumPopup(BasePopup):
               # only one possibility, just set it
               setRefExperiment(experiment, refExperiments[0])
             
-            else:
-              showPopup = True
+            # wb104: 20 Oct 2014: do not popup Experiment types dialog if noVerify
+            #else:
+            #  showPopup = True
     
     # Pop up refExperiment verification
     if experiments and (showPopup or not noVerify):
