@@ -644,10 +644,8 @@ class SecStructureGraphPopup(BasePopup):
       
       atom = residue.findFirstAtom(name=atomName)
       
-      
+      resonances = set()
       if atom and atom.atomSet:
-        resonances = set()
-        
         for resonanceSet in atom.atomSet.resonanceSets:
           for resonance in resonanceSet.resonances:
             resonances.add(resonance)
@@ -1102,6 +1100,9 @@ class SecStructureGraph(Frame):
     font = self.font
     name, size = font.split()[:2]
     smallFont = '%s %d' % (name, max(int(size)-2, 6))
+
+    # Some Mac Tk implementations use obscure font unless explicitly set fontmap
+    self.canvas.tk.call('set', 'fontmap(%s)' % smallFont, smallFont)
     
     if 'italic' not in font:
       font2 = font + ' italic'
