@@ -669,7 +669,7 @@ class ViewChemicalShiftsPopup(BasePopup):
     textWidths = {} 
     for subStrings in strings:
       for i, text in enumerate(subStrings):
-        if len(text) > textWidths.get(i, 0):
+        if text and len(text) > textWidths.get(i, 0):
           textWidths[i] = len(text)
         else:
           textWidths[i] = 0
