@@ -825,16 +825,25 @@ def makeStructureDictFromXml(path, fileName):
 
   model = structure.findFirstModel()
 
+  # set chain and residue dicts
   dict = {}
   for chain in structure.coordChains:
-    dict[chain.code] = {}
+    dd1 = dict[chain.code] = {}
     for residue in chain.residues:
-      dict[chain.code][residue.seqId] = {}
-      dict[chain.code][residue.seqId]['resName'] = residue.residue.ccpCode
-      dict[chain.code][residue.seqId]['atoms'] = {}
-      for atom in residue.atoms:
-        coord = atom.findFirstCoord(model=model)
-        dict[chain.code][residue.seqId]['atoms'][atom.name] = [coord.x, coord.y, coord.z]
+      dd2 = dd1[residue.seqId] = {}
+      dd2['resName'] = residue.residue.ccpCode
+      dd2['atoms'] = {}
+  
+  # fill in atom coordinates
+  offset = 0
+  coordinates = model.coordinates
+  for atom in structure.orderedAtoms:
+    next = offset + 3
+    residue = atom.residue
+    dict[residue.chain.code][residue.seqId]['atoms'][atom.name] = (
+     list(coordinates[offset:next])
+    )
+    offset = next
   
   del project
   
