@@ -446,9 +446,9 @@ class CnsFormat(DataFormat):
                                                   resName,
                                                   segId,
                                                   seqCode,
-                                                  self.coord.x,
-                                                  self.coord.y,
-                                                  self.coord.z,
+                                                  self.x,
+                                                  self.y,
+                                                  self.z,
                                                   insertionCode = seqInsertCode,
                                                   chainId = chainId)
       
