@@ -55,12 +55,15 @@ Development of a Software Pipeline. Proteins 59, 687 - 696.
 import copy
 
 from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords
+from ccpnmr.format.converters.DataFormat import filteredNameInfo
 
 from ccpnmr.format.general.Constants import tagSep
 from ccpnmr.format.general.Constants import defaultMolCode
 from ccpnmr.format.general.Constants import volume_kw, height_kw, ccpNmr_kw
 from ccpnmr.format.general.Util import getResName, getResNameText
 
+from ccp.lib.nmr.Nmr.DataSource import getXEasyDimCodes
+
 import ccp.api.nmr.Nmr as Nmr
 
 #
@@ -345,6 +348,12 @@ class NmrViewFormat(DataFormat):
       peakDimCodes.append(isotopeCode)
       peakDimInfo.append("Label for dimension %d (%s, %.1f)" % (expDimRef.expDim.dim,isotopeCode,sw))
       
+    if self.useXeasyDimCodes:
+      # NBNB Rasmus 5 Aug 2012. Replaced with XEASY style, so that CYANA can read it
+      # This would work globally, but the if statement avoids breaking normal use.
+      peakDimCodes = getXEasyDimCodes(self.dataSource)
+    
+    
     if not self.minimalPrompts:
     
       interaction = self.multiDialog.EntryList(
@@ -428,109 +437,80 @@ class NmrViewFormat(DataFormat):
     #
     # Transfer assignment. Code by Gary Thompson, should handle NmrView correctly!
     #
-
-    peakDim = self.peakDim.dim
-    peakDimContribSets = []
-
-
-    for peakContrib in self.peakDim.peak.sortedPeakContribs():
-
-      if len(peakContrib.peakDimContribs) == 0:
-        continue
-
-      peakDimContribSet = []
-      peakDimContribSets.append(peakDimContribSet)
-
-      for peakDimContrib in peakContrib.peakDimContribs:
-        if peakDimContrib.dim ==  peakDim:
-          peakDimContribSet.append(peakDimContrib)
-
-
-
-
-    resNameTexts = []
+    # Refactored by rasmus fogh, July 2012
+    #
     
-    for peakDimContribs in peakDimContribSets:
+    resNameTexts = []
+    peakContribs = self.peakDim.peak.sortedPeakContribs()
+    
+    if (self.writeAssignments 
+        and not (self.skipMultiAssignments and len(peakContribs) > 1)):
 
-        if self.writeAssignments and peakDimContribs != ():
+      peakDim = self.peakDim.dim
+      peakDimContribSets = []
 
-          resNames = []
-          resAtomSetNames = []
+      for peakContrib in peakContribs:
 
-          for peakDimContrib in peakDimContribs:
+        if len(peakContrib.peakDimContribs) == 0:
+          continue
 
-            if isinstance(peakDimContrib,Nmr.PeakDimContribN):
-              print "   Warning: cannot handle multiple resonances for one peakDim contribution. Ignored for peak %d " % self.peakDim.peak.serial
-              continue
+        peakDimContribSet = []
+        peakDimContribSets.append(peakDimContribSet)
 
-            resNameText = ""
-            resonance = peakDimContrib.resonance
-            resName = None
-
-            if self.resonanceToAtoms.has_key(resonance):
-
-              for resonanceToAtom in self.resonanceToAtoms[resonance]:
-
-                #
-                # Don't use chainCode for nmrView output
-                # Using chain and seqCode mapping for output
-                # Note that code same whether original res names
-                # are being used or not...
-                #
-
-                chain = resonanceToAtom.chain
-                seqId = resonanceToAtom.seqId
-
-                seqCode = self.getExportSeqCode(self.chainDict[chain][1],chain.findFirstResidue(seqId = seqId))
-
-                resName = str(seqCode) + tagSep + resonanceToAtom.atomName
-
-                if resName not in resNames:
-                  resNames.append(resName)
-
-                #
-                # Also check atomSet: use this if the same for all...
-                #
-
-                atomSetId = resonanceToAtom.getAtomSetId()
-
-                if atomSetId:
-
-                  atomName = atomSetId[2]
-
-                  resName = str(seqCode) + tagSep + atomName
-
-                  if resName not in resAtomSetNames:
-                    resAtomSetNames.append(resName)
-
-            if not resName:
-              print "  Can't handle resonance %s for peak %d" % (getResNameText(resonance), self.peak.serial)
-
-          #
-          # Use atomSet if same for all (and more than one different contrib)
-          #
-
-          #print resNames,resNameText
-          resNameText = ""
-          
-          if len(resNames) > 1 and len(resAtomSetNames) == 1 and self.compressResonances:
-            resNameText = self.assignTagSep.join(resAtomSetNames)
-            lenResNames = len(resAtomSetNames)
-          elif len(resNames) > 0:
-            resNameText = self.assignTagSep.join(resNames)
-            lenResNames = len(resNames)
+        for peakDimContrib in peakContrib.peakDimContribs:
+          if peakDimContrib.dim ==  peakDim:
+            peakDimContribSet.append(peakDimContrib)
+      
+      
+      # get and filter resonanceToAtoms
+      for peakDimContribs in peakDimContribSets:
+        # loop over contribs
+        
+        if not peakDimContribs:
+          continue
+        
+        resonanceToAtoms = []
+        for peakDimContrib in peakDimContribs:
+          ll = self.resonanceToAtoms.get(peakDimContrib.resonance)
+          if ll is None:
+            print ("  Can't handle resonance %s for peak %d" 
+                   % (getResNameText(peakDimContrib.resonance), 
+                   self.peak.serial))
           else:
-            lenResNames = 0
+            resonanceToAtoms.extend(ll)
+        
+        #  sort, filter, and transform
+        if self.presetResonanceMapping:
+          nameInfo = filteredNameInfo(resonanceToAtoms, mode='preset')
+        elif self.compressResonances:
+          nameInfo = filteredNameInfo(resonanceToAtoms, mode='compress')
+        else:
+          nameInfo = filteredNameInfo(resonanceToAtoms)
+ 
+        # now get names
+        resNames = []
+        for resonanceToAtom, atomName in nameInfo:
+          chain = resonanceToAtom.chain
+          seqId = resonanceToAtom.seqId
+          seqCode = self.getExportSeqCode(self.chainDict[chain][1],chain.findFirstResidue(seqId = seqId))
+          resName = str(seqCode) + tagSep + atomName
+          resNames.append(resName)
+        resNames.sort()
+        
+        if not (len(resNames) > 1 and self.skipMultiAssignments):
+        
+          # Make resNameText
+          resNameText = self.assignTagSep.join(resNames)
 
-          if lenResNames > 1:
+          if len(resNames) > 1:
+          #if lenResNames > 1 and len(peakDimContribSets) > 1: # NBNB Rasmus try-out
             resNameText = "{%s}" % resNameText
 
-          if resNameText not in resNameTexts:
-            resNameTexts.append(resNameText)
+          resNameTexts.append(resNameText)
 
     result  = " ".join(resNameTexts)
 
-    if len(result) == 0:
+    if not result.strip():
       result = "?"
       
     self.assign.append(result)
