@@ -56,13 +56,14 @@ import traceback, copy
 
 from ccpnmr.format.converters.DataFormat import DataFormat, IOkeywords
 
-from ccp.general.Util import setUniqueAppData, findAllSysNamesByChemAtoms, findAllSysNamesByChemAtomSets
-
+from ccp.general.Util import setUniqueAppData, findAllSysNamesByChemAtomOrSet
 from memops.universal.Util import returnInt
 
 from ccpnmr.format.general.Util import getApplResNames
 from ccpnmr.format.general.Constants import volume_kw, height_kw, peakNum_kw
 
+from ccp.lib.nmr.Nmr.DataSource import getXEasyDimCodes
+
 import memops.api.Implementation as Implementation
 import ccp.api.molecule.ChemComp as ChemComp
 import ccp.api.nmr.Nmr as Nmr
@@ -510,7 +511,7 @@ class XEasyFormat(DataFormat):
  
   def peakAssignmentsCreate(self):
     
-    if self.assignCombinations != []:
+    if self.assignCombinations:
     
       appData = self.peak.findFirstApplicationData(application = self.format, keyword = peakNum_kw)
       
@@ -594,29 +595,10 @@ class XEasyFormat(DataFormat):
 
   def setPeakFileInfo(self):    
     
-    #
-    # Get isotopecode info
-    #
-
-    for dimIndex in range(0,len(self.dataDimRefs)):
-      expDimRef = self.dataDimRefs[dimIndex].expDimRef
-      
-      elementType = expDimRef.isotopeCodes[0][-1]
-      
-      expTransfers = list(expDimRef.expTransfers)
- 
-      if len(expTransfers) == 1 and expTransfers[0].transferType == 'NOESY':
-        elementType = elementType.lower()
-      
-      self.peakFile.dimCodes[dimIndex] = elementType
-      
-    #
-    # Fix in homonuclear 2D case...
-    #
     
-    if self.peakFile.dimCodes.count(self.peakFile.dimCodes[0]) == len(self.peakFile.dimCodes):
-      if self.peakFile.dimCodes[0] == self.peakFile.dimCodes[0].lower():
-        self.peakFile.dimCodes[0] = self.peakFile.dimCodes[0].upper()
+    dimCodes = getXEasyDimCodes(self.peakList.dataSource)
+    
+    self.peakFile.dimCodes = dimCodes
 
     #
     # Also do a check for which intensity type is available, reset if not good
@@ -640,7 +622,11 @@ class XEasyFormat(DataFormat):
     #
     
 
-    if self.compressResonances and not self.useOriginalResNames:
+    
+    if self.presetResonanceMapping:
+      self.compressPresetResidueResonanceToAtomList(residueResonanceToAtomList)  
+
+    elif self.compressResonances and not self.useOriginalResNames:
       
       self.compressResidueResonanceToAtomList(residueResonanceToAtomList)    
    
@@ -663,8 +649,8 @@ class XEasyFormat(DataFormat):
         print "  ERROR: no chemCompVar found for XEasy - might be non-standard residue."
         return
         
-    chemAtomSysNames = findAllSysNamesByChemAtoms(chemCompVar.chemComp,chemCompVar.chemAtoms,self.namingSystemName)
-    chemAtomSetSysNames = findAllSysNamesByChemAtomSets(chemCompVar.chemComp,chemCompVar.chemAtomSets,self.namingSystemName)
+    chemAtomSysNames = findAllSysNamesByChemAtomOrSet(chemCompVar.chemComp,chemCompVar.chemAtoms,self.namingSystemName)
+    chemAtomSetSysNames = findAllSysNamesByChemAtomOrSet(chemCompVar.chemComp,chemCompVar.chemAtomSets,self.namingSystemName)
     namingSystem = chemCompVar.chemComp.findFirstNamingSystem(name = self.namingSystemName)
 
     for chemAtomSysName in chemAtomSysNames + chemAtomSetSysNames:
