@@ -206,6 +206,7 @@ allFormatsDict = {'amber': 'Amber',
                   'nmrPipe': 'NmrPipe',
                   'nmrStar': 'NmrStar',
                   'nmrView': 'NmrView',
+                  'pales': 'Pales',
                   'pdb': 'Pdb',
                   'pipp': 'Pipp',
                   'pistachio': 'Pistachio',
@@ -260,6 +261,7 @@ formatNamingDict = {('amber',None):      'PDB',
                     ('nmrStar','3.1'):   'PDB_REMED',
                     
                     ('nmrView',None):    'XPLOR',
+                    ('pales',None):      'IUPAC',   # Pales is naming system agnostic TODO add other naming systems?
                     ('pdb',None):        'PDB',     # This is the default naming system
                     ('pdb','2.5'):       'IUPAC',   # This is an intermediate format...
                     ('pdb','3.0'):       'PDB_REMED',  
@@ -902,6 +904,7 @@ IoSetupList = [
                                             [['SelectionList','version','Cyana version:',['2.0','2.1'],None],
                                              ['CheckButton','singleAtom','Write out with single atom for each RDC:',0,None]]],
      'module':  ['rdcs.mod',1,1,            [],[]],
+     'pales':   ['rdcs.pal',1,1,            [],[]],
      'nmrStar': ['nmrStar.str',1,0,         [],[]]},
      [['FileButton','fileName','Rdc constraints file to import:','Select file',None],
       ['SelectionListWithNone','strucGen','Add to structure generation:','project.currentNmrProject.sortedStructureGenerations()',None],
@@ -1255,6 +1258,7 @@ fileTypeDict = {
                  'cns':     ['*.tbl'],
                  'dyana':   ['*rdc*'],
                  'cyana':   ['*rdc*'],
+                 'pales':   ['*.pal','*.txt'],
                  'module':  ['*.mod'],
                  'nmrStar': ['*.str']},
 
