@@ -1969,7 +1969,7 @@ class FormatConversion(object):
 
   def runFromXml(self,xmlFileName,allowedFormats=None):
   
-    import xml.etree.ElementTree as ET
+    from memops.universal.ElementTree import ElementTree as ET
    
     root = ET.ElementTree(file=xmlFileName)
     
