@@ -571,15 +571,16 @@ class MultiDialog:
     
     nonGuiClass = NonGuiClass()
     nonGuiClass.assignFormat = self.formatNamesDict[self.formatNamesList[0]]
-    nonGuiClass.globalStereoAssign = 0
-    nonGuiClass.useIupacMatching = 1
-    nonGuiClass.useLinkResonancePopup = 0
-    nonGuiClass.minimalPrompts = 1
-    nonGuiClass.forceShiftMerge = 1
-    nonGuiClass.useAmbiguity = 0
-    nonGuiClass.verbose = 1
-    nonGuiClass.setSingleProchiral = 1
-    nonGuiClass.setSinglePossEquiv = 1
+    nonGuiClass.globalStereoAssign = False
+    nonGuiClass.useIupacMatching = True
+    nonGuiClass.useLinkResonancePopup = False
+    nonGuiClass.minimalPrompts = True
+    nonGuiClass.forceShiftMerge = True
+    nonGuiClass.useAmbiguity = False
+    nonGuiClass.verbose = True
+    nonGuiClass.setSingleProchiral = True
+    nonGuiClass.setSinglePossEquiv = True
+    nonGuiClass.makeMethylsEquivalent = True
     
     nonGuiClass.status = 1
     
