@@ -110,8 +110,6 @@ from memops.gui.DataEntry import askString, askDir, askFile
 from memops.gui.MessageReporter import showError, showYesNo, showInfo, showWarning
 from memops.gui.WebBrowser import WebBrowser
 
-from memops.editor.EditObjectPopup import EditObjectPopup
-
 ProjectMenu = 'Project'
 SetupMenu = 'Setup'
 ProcessMenu = 'Process'
@@ -801,13 +799,6 @@ class FormatConverter(BasePopup):
       showError('Saving file', str(e))
       return False
 
-  def runGeneralEditor(self):
-
-    popup = self.popups.get('general_editor')
-    if (popup):
-      popup.open()
-    else:
-      self.popups['general_editor'] = EditObjectPopup(self,metaclass = self.project.metaclass, object = self.project)
 
   def askSaveFile(self):
 
