@@ -1147,19 +1147,23 @@ def runCyana2CcpnDialogue(argServer, protocolName, prelimProtocolName=None,
     xx = argServer.askYesNo("Run Calculation")
     if xx:
       if executeScript:
-        process = subprocess.call(['python', executeScript])
+        process = subprocess.call([sys.executable, executeScript])
         #print 'CCPN executing %s process: %s' % (protocolName,pid)
         # process.poll()
         #
         # if process.returncode is not None:
-        yy = argServer.askYesNo("Import Calculation Results?")
-        if yy:
-          targetDir = nmrCalcDir(nmrCalcRun)
-          importFromCyana(nmrCalcRun,targetDir)
+        # yy = argServer.showInfo("Calculation complete")
+        # if yy:
+        targetDir = nmrCalcDir(nmrCalcRun)
+        #   importFromCyana(nmrCalcRun,targetDir)
+        calculationData=(nmrCalcRun, targetDir)
+
       else:
        print 'CCPN not executing %s - no script generated' % protocolName
     else:
       pass
+    print "calculationData",calculationData
+    return calculationData
 
 def setupPreviousCalculation(argServer, protocolName, prelimProtocolName=None,
                            masterRun=None):
@@ -1203,8 +1207,8 @@ def importDataFromCyana(argServer):
     nmrCalcId=jsonObj['CCPN.nmrCalcId']
     nmrCalcRun = getNmrCalcRunFromId(currentProject, nmrCalcId)
     targetDir = nmrCalcDir(nmrCalcRun)
-    importFromCyana(nmrCalcRun,targetDir)
-    return nmrCalcRun
+    dataSources = importFromCyana(nmrCalcRun,targetDir)
+    return dataSources
 
 
 def setupSingleInteractive(argServer, protocolName, prelimProtocolName=None,
