@@ -632,7 +632,7 @@ class ReleaseUpdate:
           use_precompiled = True
         elif platform == 'darwin':
           if arch in ('i386', 'intel'):
-            arch = 'intel'
+            arch = 'intel%s' % bits
           else:
             arch = 'ppc'
           ss =  '_%s' % arch
@@ -708,7 +708,7 @@ class ReleaseUpdate:
         # move all of ccpnmr
         self.moveAllRelease()
         self.compileAllPyCode()
-        self.runConfigScript()
+        #self.runConfigScript()
       else:
         # move only ccpnmr/ccpnmrX.Y
         self.compileCCode() # What if this fails?
