@@ -98,7 +98,7 @@ from cyana2ccpn.classes4 import RDCRestraint
 from cyana2ccpn.classes4 import RDCRestraintList
 from cyana2ccpn.classes4 import ChemicalShiftRestraint
 from cyana2ccpn.classes4 import ChemicalShiftRestraintList
-import pprint as pp
+import json
 
 CYANA_CHAIN_ID = 'A'
 CYANA_NON_RESIDUES = ['PL','LL2','link']
@@ -231,7 +231,7 @@ class AtomRecord( ntu.NTtree ):
 
 
 def findTupleInDict( myDict, *args):
-    """Convienience methods to find a tuple defined by args.
+    """Convenience methods to find a tuple defined by args.
     returns item if present or None otherwise.
     test for empty dicts.
     """
@@ -276,6 +276,7 @@ class CyanaParser(dict):
         self.peakFiles      = None
         self.cyaFiles       = None
         self.uplFiles       = None
+        self.txtFiles       = None
         self.lolFiles       = None
         self.acoFiles       = None
         self.rdcFiles       = None
@@ -296,6 +297,7 @@ class CyanaParser(dict):
               peakFiles = ntu.NTlist(),
               xpkFiles  = ntu.NTlist(),
               noaFiles  = ntu.NTlist(),
+              txtFiles  = ntu.NTlist(),
               uplFiles  = ntu.NTlist(),
               lolFiles  = ntu.NTlist(),
               acoFiles  = ntu.NTlist(),
@@ -314,6 +316,7 @@ class CyanaParser(dict):
         self.peakFiles  = peakFiles
         self.xpkFiles   = xpkFiles
         self.noaFiles   = noaFiles
+        self.txtFiles   = txtFiles
         self.uplFiles   = uplFiles
         self.lolFiles   = lolFiles
         self.acoFiles   = acoFiles
@@ -347,6 +350,8 @@ class CyanaParser(dict):
                     self.uplFiles.append(f)
                 elif ext == '.noa':
                     self.noaFiles.append(f)
+                elif ext == '.txt':
+                    self.txtFiles.append(f)
                 elif ext == '.lol':
                     self.lolFiles.append(f)
                 elif ext == '.aco':
@@ -359,6 +364,7 @@ class CyanaParser(dict):
             self.rootPath = 'Undefined'
         #end if
 
+
         self._atomDict = {}
         # parse seqFile and finalProtFile to assemble the sequence, atoms and resonances lists
         if self.seqFile != None and self.finalProtFile != None:
@@ -393,10 +399,16 @@ class CyanaParser(dict):
                 self.peakLists.append(peakList)
             #end if
         #end for
+        ccpnConfigFile = open("Properties.ccpn.json")
+        ccpnConfig = json.load(ccpnConfigFile)
+        violationLimit = float(ccpnConfig["violationLimit"])
         for f in self.noaFiles:
-                  violationList = self.parseNoaFile(f)
+                  violationList = self.parseNoaFile(f, violationLimit)
+                  distanceList = self.getDistanceRestraintsFromNoa(f)
                   if violationList != None:
                       self.violationLists.append(violationList)
+                  if distanceList != None:
+                    self.distanceRestraintLists.append(distanceList)
                   #end if
               #end for
 
@@ -1097,7 +1109,59 @@ problem resides in the multiple assignments that alters format
         return self
     #end def
 
-    def parseNoaFile (self, noaFile):
+
+    def getDistanceRestraintsFromNoa(self, noaFile):
+
+      maxErrorCount = 50
+      errorCount = 0
+      name,_ext = noaFile.split('.noa')
+      if name == 'cycle7':
+        listName = 'final'
+      else:
+        listName = name
+
+      result = DistanceRestraintList( name=listName, status='keep')
+
+      for line in AwkLike ( noaFile ):
+        if line.NF >=7 and line[1] == 'Peak' and line[line.index('ppm;')+1] != 'diagonal):':
+            peakId  = line[2]
+            peakListName = line[4].split('.peaks')[0]
+            upper = line[line.index('ppm;')+1]
+            assignments = int(line.next()[4])
+            for i in range(assignments):
+              nextLine = line.next()
+              if 'Violated' not in nextLine and '+' in nextLine:
+                atmIdxList = [[3,1],[7,5]]
+                atmList = []
+                if '!' in nextLine:
+                  i = nextLine.index('!')
+                  del nextLine[i]
+                if '*' in nextLine:
+                  i = nextLine.index('*')
+                  del nextLine[i]
+                for atmIdx in atmIdxList:
+                  sequenceId = int(nextLine[atmIdx[0]])
+                  atomId = nextLine[atmIdx[1]]
+                  atm = findTupleInDict(self._atomDict, sequenceId, atomId)
+                  if not atm:
+                      if errorCount <= maxErrorCount:
+                          ntu.nTerror('CyanaParser.parseUplFile: Failed to decode for sequenceId %d atomId %s; line: %s', sequenceId, atomId, line[0] )
+                      if errorCount == maxErrorCount+1:
+                          ntu.nTerror("And so on")
+                      errorCount += 1
+                      continue
+                  #end if
+                  atmList.append( atm )
+              #end for
+                if len(atmList) != 2:
+                  continue
+                atm1 = atmList[0]
+                atm2 = atmList[1]
+                r = DistanceRestraint( atomPairs= [(atm1,atm2)], lower=0.0, upper=upper, peakList=peakListName+'-'+name, peak = peakId)
+                result.append(r)
+      return result
+
+    def parseNoaFile (self, noaFile, violationLimit):
       """
       Peak 1740 from 1308PAR_6ms_SSB2p5.peaks (21.79, 21.14 ppm; 5.50 A):
       0 out of 4 assignments used, quality = 0.00:
@@ -1115,23 +1179,29 @@ problem resides in the multiple assignments that alters format
       name,_ext = noaFile.split('.noa')
       result = DistanceRestraintList( name=name, status='keep')
       violatedPeaks = {}
-
       for line in AwkLike ( noaFile ):
          if line.NF >=7 and line[1] == 'Peak':
-           violatedPeaks[line[4].split('.peaks')[0]] = {}
+           violatedPeaks[line[4].split('.peaks')[0]] = []
       for line in AwkLike ( noaFile ):
          if line.NF >=7 and line[1] == 'Peak':
             peakId  = line[2]
             peakListName = line[4].split('.peaks')[0]
-         if line.NF > 5 and line[1] == 'Violated' and line[3] != "0" and float(line[6]) >= 1.0:
-            violatedPeaks[peakListName][peakId] = []
+         if line.NF > 5 and line[1] == 'Violated' and line[3] != "0" and float(line[6]) >= float(violationLimit):
+            violatedPeaks[peakListName].append(peakId)
       for line in AwkLike ( noaFile ):
-        if line.NF >=7 and line[1] == 'Peak':
+        if line.NF >=7 and line[1] == 'Peak' and line[line.index('ppm;')+1] != 'diagonal):':
             peakId  = line[2]
             peakListName = line[4].split('.peaks')[0]
-            if peakId  in violatedPeaks[peakListName]:
+            upper = line[line.index('ppm;')+1]
+            # if len(line) == 12:
+            #   upper = line[10]
+            # elif len(line) == 11:
+            #   upper = line[9]
+            # elif len(line) == 10:
+            #   upper = line[8]
+            # print len(line), upper
+            if peakId in violatedPeaks[peakListName]:
               assignments = int(line.next()[4])
-              peakAssignments = []
               for i in range(assignments):
                 nextLine = line.next()
                 if 'Violated' not in nextLine:
@@ -1140,6 +1210,9 @@ problem resides in the multiple assignments that alters format
                   if '!' in nextLine:
                     i = nextLine.index('!')
                     del nextLine[i]
+                  if '*' in nextLine:
+                    i = nextLine.index('*')
+                    del nextLine[i]
                   for atmIdx in atmIdxList:
                     sequenceId = int(nextLine[atmIdx[0]])
                     atomId = nextLine[atmIdx[1]]
@@ -1158,12 +1231,12 @@ problem resides in the multiple assignments that alters format
                     continue
                   atm1 = atmList[0]
                   atm2 = atmList[1]
-                  upper = float(nextLine[13].split('-')[1])
-                  lower = float(nextLine[13].split('-')[0])
-                  r = DistanceRestraint( atomPairs= [(atm1,atm2)], lower=lower, upper=upper, peakList=peakListName+'-'+noaFile.split('.')[0], peak = peakId)
+
+                  r = DistanceRestraint( atomPairs= [(atm1,atm2)], lower=0.0, upper=upper, peakList=peakListName+'-'+name, peak = peakId)
                   result.append(r)
       return result
 
+
     def parseUplFile( self, uplFile, lower = 0.0 ):
         """
         Read Cyana upl file
@@ -1435,7 +1508,7 @@ problem resides in the multiple assignments that alters format
           ## filters out CYANA dihedral files that contain multiple dihedrals per residue
 
             sequenceId   = line.int(1)
-            residueId    = line[2].strip()
+            residueId    = line[2].strip()[:3]
             dihedralName = line[3].strip()
             lower        = line.float(4)
             upper        = line.float(5)
