@@ -47,7 +47,7 @@ def importFromCyana(nmrCalcRun, targetDir):
   cyaFiles = []
   noaFiles = []
   txtFiles = []
-
+  dataSources = []
   ccpnConfigFile = open("Properties.ccpn.json")
   ccpnConfig = json.load(ccpnConfigFile)
   configFile = open("cyana2ccpn.json")
@@ -101,6 +101,7 @@ def importFromCyana(nmrCalcRun, targetDir):
     cloneName = ccpnExperiment.name + '_run' + str(runId)
     clonedExperiment = cloneExperiment(ccpnExperiment, cloneName)
     spectrum = clonedExperiment.findFirstDataSource()
+    dataSources.append(spectrum)
     setExperimentShiftList(clonedExperiment, newShiftList)
     peakList = spectrum.newPeakList()
     spectrum.activePeakList = peakList
@@ -149,8 +150,8 @@ def importFromCyana(nmrCalcRun, targetDir):
 
   pluginModule = intUtil.getIntegratorPlugin(ccpnConfig["CCPN.Run.wmsProtocolName"])
   pluginModule.read.read(nmrCalcRun, targetDir)
-  # print dir(Cyana.read)
   print "Import Complete"
+  return dataSources
 
 
 
@@ -215,15 +216,14 @@ def assignResonances(resonances, atomToResonanceMap,molSystem, ccpnShiftList, An
         seqId=ccpnResidue.seqId)
       ccpnAtomMapping = ccpnResidueMapping.findFirstAtomSetMapping(name=ccpnMappingAtomName)
 
-      atomTuple = (ccpnChainCode, ccpnResNum, ccpnRealAtomName)
-      try:
-        if atomTuple not in atomTupleDict:
-          atomTupleDict[atomTuple] = cingResonance
-        resonance = atomToResonanceMap[atomTuple]
-        assignAtomsToRes(ccpnAtomMapping.atomSets, resonance)
+      atomTuple = (ccpnChainCode, ccpnResidue.seqId, ccpnRealAtomName)
+      if atomTuple not in atomTupleDict:
+        atomTupleDict[atomTuple] = cingResonance
+      resonance = atomToResonanceMap[atomTuple]
+      assignAtomsToRes(ccpnAtomMapping.atomSets, resonance)
 
-      except KeyError:
-        pass
+      # except KeyError:
+      #   pass
 
 
 
@@ -239,7 +239,8 @@ def assignResonances(resonances, atomToResonanceMap,molSystem, ccpnShiftList, An
 
       ccpnChainCode = molSystem.findFirstChain(code=cingResonance.atom.chainId)
       ccpnResNum = cingResonance.atom.sequenceId
-      atomTuple = (ccpnChainCode, ccpnResNum, ccpnRealAtomName)
+      ccpnResidue = molSystem.findFirstChain().findFirstResidue(seqCode=ccpnResNum)
+      atomTuple = (ccpnChainCode, ccpnResidue.seqId, ccpnRealAtomName)
       if atomTuple not in atomTupleDict:
         atomTupleDict[atomTuple] = cingResonance
 
@@ -278,15 +279,18 @@ def pickPeaksFromCing(cingPeakList, peakList, resonanceDict):
         resonance = resonanceDict.get(cingResonance)
         if resonance is not None:
           assignResToDim(peakDim, resonance)
+
     else:
+      # original, fixed
       for j, peakDim in enumerate(peak.sortedPeakDims()):
         numAssignments = len(cingPeak.resonances) / len(peak.peakDims)
         ccpnResonances = []
+        indx = j
         for k in range(numAssignments):
-          cingResonance = cingPeak.resonances[j]
+          cingResonance = cingPeak.resonances[indx]
           resonance = resonanceDict.get(cingResonance)
           ccpnResonances.append(resonance)
-          j += len(peak.peakDims)
+          indx += len(peak.peakDims)
         for res in ccpnResonances:
           if res is not None:
             assignResToDim(peakDim, res)
@@ -410,7 +414,8 @@ def loadViolatedDistanceRestraints(cingRestraintList, nmrProject, nmrCalcRun, nm
             if ll is None:
               violatedPeaks[peakList] = [peak]
             else:
-              ll.append(peak)
+              if peak not in ll:
+                ll.append(peak)
         except (AttributeError, TypeError):
           pass
       if None not in ccpnPeaks:
