@@ -23,8 +23,6 @@ from memops.gui.WebBrowser  import WebBrowser
 
 from ccp.api.nmr import NmrCalc
 
-from ccpnmr.analysis.core.StructureBasic import getStructureFromFile, makePdbFromStructure
-
 from gottingen import Io as palesIo
 
 # Max length for file name shown in table (longer are truncated)
@@ -793,48 +791,6 @@ class PalesFrame(Frame):
     
     row = 0
     
-    #loadButton = Button(frameB, text='Load New Run',bd=1,bg='#B0FFB0',
-    #                    command=self.loadPalesRun, grid=(1,3), sticky="ew")
-                    
-    #label = Label(frameB, text='Select Run:',
-    #              grid=(row,2), sticky='e')
-    #self.runPulldown = PulldownList(frameB, callback=self.changeRun,
-    #                                grid=(row,3), sticky='w')
-     
-    #row += 1 
-    #texts = ['Delete Run']
-    #commands = [self.deleteRun]
-    
-    #if closeButton:
-    #  ButtonListClass = UtilityButtonList
-    #else:
-    #  ButtonListClass = ButtonList
-    
-    #runButtons = ButtonListClass(frameB, texts=texts,
-    #                             commands=commands, 
-    #                             grid=(row,3), sticky='w')
-                                
-    #row += 1 
-    #button = Button(frameB, text='Select script file:',bd=1,
-    #                command=self.selectRunFile, grid=(row,0), sticky="ew")
-    ##label = Label(frameB, text='Load script file:', grid=(1,1))
-    #self.runFileEntry = Entry(frameB, text='', grid=(row,1), 
-    #                     gridSpan=(1,3), width=48, sticky="ew", bd=1)
-                    
-    #row += 1 
-    #button = Button(frameB, text='Load Pales Run', bd=1,
-    #                command=self.loadPalesRun, grid=(row,0), sticky="ew")
-                  
-    #label = Label(frameB, text='Pales mode', grid=(row,0), sticky="w")
-    #self.modeEntry = Entry(frameB, grid=(row,1), sticky="w")
-    #self.modeEntry.set('SVD')
-    
-    #row += 1     
-    #frameB = LabelFrame(frameB, text='Run data:', grid=(row,0), gridSpan=(1,4))
-    #frameB.grid_columnconfigure(2, weight=1)
-    #frameB.expandGrid(6,0)
-    #frameB.expandGrid(6,1)
-    
       
     subframe1 = LabelFrame(frameB, text='Command Options:', grid=(row,0), 
                            gridSpan=(1,4))
@@ -845,38 +801,20 @@ class PalesFrame(Frame):
         
     row += 1  
     div = LabelDivider(frameB, text='Data', grid=(row,0), gridSpan=(1,4))
-    
-    #div = LabelDivider(frameB, text='Output Data', grid=(1,1))
                
     row += 1          
     
     self.outputMatrix = GenericDataMatrix(frameB, progParameters, 
                                            initialRows=4)
     self.outputMatrix.grid(row=0, column=0, sticky='nsew')
-    #headingList = ['Type', 'I/O', 'Data']
-    #nothing = [None, None, None]
-    #self.outputMatrix = ScrolledMatrix(frameB, headingList=headingList,
-    #                                    editSetCallbacks=nothing,
-    #                                    editGetCallbacks=nothing, 
-    #                                    editWidgets=nothing,
-    #                                    initialRows=4)
+    
     self.outputMatrix.grid(row=row, column=0, columnspan=(4), sticky='nsew')
                        
-    #self.runOutputMatrix = ScrolledMatrix(frameB, headingList=headingList,
-    #                                    editSetCallbacks=nothing,
-    #                                    editGetCallbacks=nothing, 
-    #                                    editWidgets=nothing,
-    #                                    initialRows=3)
-    #self.runOutputMatrix.grid(row=2, column=1, sticky='nsew')
     
     row += 1     
     button = Button(frameB, text='View Selected',bd=1,
                     command=self.viewPalesData, grid=(row,0), gridSpan=(1,4), 
                     sticky="ew")
-    
-    #button = Button(frameB, text='View Selected',bd=1,
-    #                command=self.viewPalesOutput, grid=(3,1), sticky="ew")
-
                     
     row += 1 
     label = Label(frameB, text='Comments:', grid=(row,0), sticky="w")
@@ -917,37 +855,6 @@ class PalesFrame(Frame):
     self.updateAfter()
     self.administerNotifiers(self.parent.registerNotify)
   
-  #def updateInputMatrix(self):
-  #  
-  #  palesMode =self.palesMode
-  #  dd = palesModes.get(palesMode)
-  #  rowLabels = []
-  #  if dd:
-  #    rowLabels = dd.get('mandatories') or []
-  #  self.inputMatrix.updateGeneric(run=self.run, paramList=rowLabels)
-  
-  #def updateExtraInputMatrix(self):
-    
-  #  palesMode =self.palesMode
-  #  dd = palesModes.get(palesMode)
-  #  rowLabels = []
-  #  if dd:
-  #    rowLabels = dd.get('optionals') or []
-  #  self.extraInputMatrix.updateGeneric(run=self.run, paramList=rowLabels)
-  
-  #def updateOutputMatrix(self):
-    
-  #  palesMode =self.palesMode
-  #  dd = palesModes.get(palesMode)
-  #  rowLabels = []
-  #  if dd:
-  #    rowLabels = dd.get('output') or []
-    
-  #  # NBNB TBD add optionalOutput with suitable conditionals
-    
-  #  self.outputMatrix.updateGeneric(run=self.run, paramList=rowLabels)
-  
-  
   
   def updatePalesOptions(self):
     
@@ -1236,21 +1143,6 @@ class PalesFrame(Frame):
   def update(self, obj=None):
     print '### update', self.run
     
-    #if run is None:
-    #  if self.run is None:
-    #    pass
-    #  elif self.run.isDeleted:
-    #    self.run = None
-    #  else:
-    #    run = self.run
-    
-    #elif run.nmrCalcStore is not self.calcStore:
-    #  run = self.run = None
-      
-    #elif self.run is not run:
-    #  self.run = run
-    #  self.updateRuns()
-    
     
     self.updateRuns(obj)
     
@@ -1335,7 +1227,7 @@ class PalesFrame(Frame):
     'SpinSystemData', 
     'StructureEnsembleData', 
     'ExternalData', 
-    'MatrixData', 
+    'FloatMatrixData', 
     'TensorData', 
     'MeasurementListData', 
     'DerivedListData', 
@@ -1385,611 +1277,3 @@ class PalesFrame(Frame):
         popup.tabbedFrame.select(2)
         popup.changeRestraintList(constraintLists[0])
   
-  ##################################################################
-  ##################################################################
-  ##################################################################
-    
-  """
-
-  def executePales(self):
-    
-    useDir = self.workingDirEntry.get() or os.getcwd()
-    if useDir == '.':
-      useDir = os.getcwd()
-    
-    palesCommand = self.palesCommandEntry.get()
-    
-    p = subprocess.check_call(palesCommand, cwd=useDir)
-    
-    options = palesIo.parsePalesCommand(palesCommand)
-    
-    # get pdb input
-    for option in ('pdb', 'pdbF'):
-      fileName = options.get(option)
-      if fileName is not None:
-        break
-    
-    #NBNB here!
-        
-        
-    
-  def exportStrucFile(self, filename='ref.pdb'):
-    
-    model = self.inpStructure
-    if not model:
-      return
-      
-    dirname = self.workingDirEntry.get() or '.'
-    
-    #
-    ee = model.strucureEnsemble
-    makePdbFromStructure(uniIo.joinPath(dirname, filename), ee, model=model)
-    
-    print ('Done exporting structure %s:%d:%d' % 
-           (ee.molSystem.code, ee.ensembleId, model.serial))
-    
-  def exportConstraintsFile(self, filename='dObs.tab'):
-    constraintList = self.inpConstraintList
-    if not constraintList:
-      return
-    dirname = self.workingDirEntry.get() or '.'
-    
-    stream = open(uniIo.joinPath(dirname, filename), 'w')
-    palesIo.writeConstraintList(stream, constraintList)
-    stream.close()
-
-  def changeInpStructure(self, structure):
-    
-    self.inpStructure = structure
-
-  def changeInpConstraintList(self, constraintList):
-  
-    self.inpConstraintList = constraintList
-
-
-  def changeExtraConstraintList(self, constraintList):
-  
-    self.extraConstraintList = constraintList
-    
-
-  def getConstraintLists(self, className=None):
-  
-    constraintLists = []
-    for nmrConstraintStore in self.parent.project.sortedNmrConstraintStores():
-      for constraintList in nmrConstraintStore.sortedConstraintLists():
-        if not className or constraintList.className == className:
-          constraintLists.append(constraintList)
-    #
-    return constraintLists
-
-  def updateInpConstraintList(self, obj=None):
-    
-    index      = -1
-    
-    constraintLists = self.getConstraintLists(className='RdcConstraintList')
-    
-    names = []
-      
-    if constraintLists:
-    
-      for rdcList in constraintLists:
-        store = rdcList.nmrConstraintStore
-        name = '%d:%d' % (store.serial, rdcList.serial) 
-        names.append(name)
-    
-      if self.inpConstraintList not in constraintLists:
-        self.inpConstraintList = constraintLists[0]
-        
-      index = constraintLists.index(self.inpConstraintList)  
-
-    else:
-      self.inpConstraintList = None
-    
-    self.inpConstraintsPulldown.setup(names, constraintLists, index)
-    self.extraConstraintsPulldown.setup(['< N/A >'], [None], 0)
-
-  def getStructures(self):
-    
-    structures = [z for x in self.project.sortedMolSystems()
-                    for y in x.sortedStructureEnsembles()
-                    for z in y.sortedModels()
-                  ]
-    #
-    return structures
-
-  def updateInpStructure(self, obj=None):
-    
-    structures = self.getStructures()
-    names = []
-    for structure in structures:
-      ee = structure.structureEnsemble
-      names.append('%s:%d:%d' 
-                   % (ee.molSystem.code, ee.ensembleId, structure.serial))
-    
-    index = 0
-    if not structures:
-      self.inpStructure = None
-      
-    elif self.inpStructure is None:
-      self.inpStructure = structures[0]
-      
-    else:
-      try:
-        index = structures.index(self.inpStructure)
-      except ValueError:
-        self.inpStructure = structures[0]
-    
-    self.inpStructurePulldown.setup(names, structures, index)
-    
-    
-  def loadPalesRun(self):
-    
-    # Load script
-    fileName = self.runFileEntry.get()
-    scriptData = palesIo.parsePalesScript(open(fileName).read())
-    command  = scriptData['command']
-    commandOptions = palesIo.parsePalesCommand(command)
-    
-    # make new run
-    newRun = self.calcStore.newRun(status='completed')
-    self.run = newRun
-    
-    # set command
-    newRun.newRunParameter(code='command', name='command', textValue=command)
-    
-
-    
-  #def viewPalesOutput(self):
-  #  pass
-
-  def selectRunFile(self):
-    
-    popup = FileSelectPopup(self, show_file=False)
-
-    fileName = popup.getFile()
-    if fileName:
-      oldFileName = self.runFileEntry.get()
-      if oldFileName != fileName:
-        self.runFileEntry.set(fileName)
-        self.run = None
-        self.updateAfter()
-    
-    popup.destroy()
-    #self.updateEntryParams()
-  
-  def administerNotifiers(self, notifyFunc):
-    
-    for func in ('__init__','delete'):
-      notifyFunc(self.updateInpStructure, 'ccp.molecule.MolStructure.Model', func)
-      notifyFunc(self.updateInpConstraintList, 'ccp.nmr.NmrConstraint.NmrConstraintStore', func)
-      for className in ('RdcConstraintList',):
-        notifyFunc(self.updateInpConstraintList, 'ccp.nmr.NmrConstraint.'+className, func)
-    
-    notifyFunc(self.resetCalcStore, 'ccp.nmr.NmrCalc.NmrCalcStore', 'delete')
-    
-    NC = 'ccp.nmr.NmrCalc.'
-    
-    for func in ('__init__', 'delete', 'setDetails'):
-      notifyFunc(self.updateRunAfter, NC+'Run', func)
-    
-
-    for func in ('__init__', 'delete', 'setGroupId','setName',
-                 'setFloatValue','setIntValue','setBooleanValue',
-                 'setTextValue',):
-      notifyFunc(self.updateRunParam, NC+'RunParameter', func)
-
-    for className in ('ConstraintStoreData', 'DerivedListData', 'ExternalData',
-                      'MeasurementListData', 'MolResidueData', 'MolSystemData',
-                      'PeakListData', 'SpectrumData', 'SpinSystemData',
-                      'StructureEnsembleData', 'ViolationListData'):
-      for func in ('__init__', 'delete', 'setDetails', 'setIoRole',
-                   'setWeight', 'setName', 'addRunParemeter',
-                   'removeRunParameter', 'setRunParameters'):
-        notifyFunc(self.updateRunData, NC+className, func)
-      
-    notifyFunc(self.updateRunData, NC+'ConstraintStoreData', 'setConstraintStoreSerial')
-    notifyFunc(self.updateRunData, NC+'ConstraintStoreData', 'setConstraintListSerials')
-    notifyFunc(self.updateRunData, NC+'ConstraintStoreData', 'addConstraintListSerial')
-    notifyFunc(self.updateRunData, NC+'ConstraintStoreData', 'removeConstraintListSerial')
-    notifyFunc(self.updateRunData, NC+'DerivedListData', 'setDerivedDataListSerial')
-    notifyFunc(self.updateRunData, NC+'ExternalData', 'setDataStore')
-    notifyFunc(self.updateRunData, NC+'MeasurementListData', 'setMeasurementListSerial')
-    notifyFunc(self.updateRunData, NC+'MolResidueData', 'setMolSystemCode')
-    notifyFunc(self.updateRunData, NC+'MolResidueData', 'setChainCode')
-    notifyFunc(self.updateRunData, NC+'MolResidueData', 'setResidueSeqIds')
-    notifyFunc(self.updateRunData, NC+'MolResidueData', 'addResidueSeqId')
-    notifyFunc(self.updateRunData, NC+'MolResidueData', 'removeResidueSeqId')
-    notifyFunc(self.updateRunData, NC+'MolSystemData', 'setMolSystemCode')
-    notifyFunc(self.updateRunData, NC+'MolSystemData', 'setChainCodes')
-    notifyFunc(self.updateRunData, NC+'MolSystemData', 'addChainCode')
-    notifyFunc(self.updateRunData, NC+'MolSystemData', 'removeChainCode')
-    notifyFunc(self.updateRunData, NC+'MolSystemData', 'setSymmetrySetId')
-    notifyFunc(self.updateRunData, NC+'PeakListData', 'setExperimentSerial')
-    notifyFunc(self.updateRunData, NC+'PeakListData', 'setDataSourceSerial')
-    notifyFunc(self.updateRunData, NC+'PeakListData', 'setpeakLisrSerial')
-    notifyFunc(self.updateRunData, NC+'SpectrumData', 'setExperimentSerial')
-    notifyFunc(self.updateRunData, NC+'SpectrumData', 'setDataSourceSerial')
-    notifyFunc(self.updateRunData, NC+'SpinSystemData', 'setResonanceGroupSerial')
-    notifyFunc(self.updateRunData, NC+'StructureEnsembleData', 'setMolSystemCode')
-    notifyFunc(self.updateRunData, NC+'StructureEnsembleData', 'setEnsembleId')
-    notifyFunc(self.updateRunData, NC+'StructureEnsembleData', 'setModelSerials')
-    notifyFunc(self.updateRunData, NC+'StructureEnsembleData', 'addModelSerial')
-    notifyFunc(self.updateRunData, NC+'StructureEnsembleData', 'removeModelSerial')
-    notifyFunc(self.updateRunData, NC+'ViolationListData', 'setConstraintStoreSerial')
-    notifyFunc(self.updateRunData, NC+'ViolationListData', 'setViolationListSerial ')
-        
-    #for func in ('__init__','delete'):
-    #  notifyFunc(self.updateMolSystemPulldown, 'ccp.molecule.MolSystem.MolSystem', func)
-    #  notifyFunc(self.updateChainPulldown, 'ccp.molecule.MolSystem.Chain', func)
-
-    #  if PEAK_DATA in self.inputTypes:
-    #    notifyFunc(self.updatePeakLists, 'ccp.nmr.Nmr.PeakList', func)
-
-    #  if MEASUREMENT_DATA in self.inputTypes:
-    #    notifyFunc(self.updateMeasurementLists, 'ccp.nmr.Nmr.ShiftList', func)
-      
-    # if STRUCTURE_DATA in self.inputTypes:
-    #   notifyFunc(self.updateModels, 'ccp.molecule.MolStructure.Model', func)
- 
-    # if CONSTRAINT_DATA in self.inputTypes:
-    #   notifyFunc(self.updateConstraintLists, 'ccp.nmr.NmrConstraint.NmrConstraintStore', func)
-    #   for className in ('ChemShiftConstraintList', 'CsaConstraintList',
-    #                     'DihedralConstraintList', 'DistanceConstraintList',
-    #                     'HBondConstraintList', 'JCouplingConstraintList',
-    #                     'RdcConstraintList'):
-    #     notifyFunc(self.updateConstraintLists, 'ccp.nmr.NmrConstraint.'+className, func)
-        
-  
-  def updateRunParam(self, runParam):
-  
-    self.updateRunAfter(runParam.run)
- 
-  def update(self, run=None):
-    
-    self.updatePalesModes()
-    
-    # NBNB Here
-    
-    #self.updateInpConstraintList()
-    #self.updateInpStructure()
-    
-    if self.calcStore is None or self.calcStore.isDeleted:
-      self.resetCalcStore()
-    
-    if run is None:
-      if self.run is None:
-        pass
-      elif self.run.isDeleted:
-        self.run = None
-      else:
-        run = self.run
-    else:
-      self.run = run
-    
-    
-    if run is None:
-      self.detailsEntry.set(None)
-      self.palesCommandLabel.set('')
-      for label in self.outputTensorLabels:
-        label.set('<None>')
-      self.palesOutputText.setText()
-      
-    
-    else:
-      # Run Details
-      self.detailsEntry.set(run.details)
-      
-      # Pales command
-      valueObj = run.findFirstRunParameter(code='command')
-      if valueObj is None:
-        self.palesCommandLabel.set('')
-      else:
-        self.palesCommandLabel.set(valueObj.textValue)
-    
-      # Output orientation matrix
-      keywords =('dAxialOut', 'dRhombicOut', 'psiOut', 'phiOut', 'thetaOut')
-      for ii, label in enumerate(self.outputTensorLabels):
-        keyword = keywords[ii]
-        valueObj = run.findFirstRunParameter(code=keyword)
-        if valueObj is None:
-          label.set('<None>')
-        else:
-          label.set(valueObj.floatValue)
-      
-      # Pales output text
-      # NBNB TBD change when model allows long strings for RunParameters
-      valueObj = run.findFirstApplicationData(application='PALES', 
-                                              keyword='output')
-      if valueObj:
-        self.palesOutputText.setText(valueObj.value)
-      else:
-        self.palesOutputText.setText()
-      
-      objectList = []
-      textMatrix= []
-      
-      for valueObj in run.sortedData():
-        name = valueObj.name
-        ioRole = valueObj.ioRole
-        if isinstance(valueObj, NmrCalc.ExternalData):
-          dataStore = valueObj.dataStore
-          if dataStore is None:
-            text = '<Not found>'
-          else:
-            fullPath = dataStore.fullPath
-            if len(fullPath) < maxFileNameLength:
-              text = fullPath
-            else:
-              text = '...' + fullPath[-maxFileNameLength:]
-          
-        elif isinstance(valueObj, NmrCalc.MeasurementListData):
-          mm = valueObj.measurementList
-          if mm is None:
-            text = '<Not found>'
-          else:
-            text = '%s:%d(%s)' % (self.nmrProject.name, mm.serial, mm.name)
-            
-        elif isinstance(valueObj, NmrCalc.StructureEnsembleData):
-          models = valueObj.models
-          if len(models) == 1:
-            ee = valueObj.structureEnsemble
-            text = '%s:%d:%d' % (ee.molSystem.code,ee.ensembleId, models[0].serial) 
-          else:
-            text = '<Not found>'
-            
-        elif isinstance(valueObj, NmrCalc.ConstraintStoreData):
-          constraintLists = valueObj.constraintLists
-          if len(constraintLists) == 1:
-            ee = valueObj.nmrConstraintStore
-            text = '%d:%d' % (ee.serial, constraintLists[0].serial) 
-          else:
-            text = '<Not found>'
-        
-        objectList.append(valueObj)
-        textMatrix.append([name, ioRole, text])
-      
-      self.outputMatrix.update(objectList=objectList, textMatrix=textMatrix)
-    
-        
-    self.after_idle(lambda:self.configure(cursor=""))
-    self.waiting = False
-    # NBNB temp:
-    return
-
-    # Should confirm any changes where a run has generated output
-    self.configure(cursor="watch")
-  
-    if not calcStore:
-      calcStore = self.calcStore
-    else:
-      self.calcStore = calcStore
-
-    if self.calcStore:
-      self.project = self.calcStore.root
-      self.nmrProject = self.project.currentNmrProject or \
-                        self.project.findFirstNmrProject() or \
-                        self.project.newNmrProject(name='default')
-      
-      if (not self.run) or (self.run.parent is not self.calcStore):
-        self.run = self.calcStore.findFirstRun()
-    
-    
-    buttons = self.buttons
- 
-    if runIsEditable():
-      for button in buttons:
-        button.enable()
-    
-    else:
-      for button in buttons:
-        button.disable()
-    
-    self.updateRuns()
-    self.updateMolSystemPulldown()
-    self.updateDetails()
-    
-    
-    if MEASUREMENT_DATA in self.inputTypes:
-      self.updateMeasurementLists()
-    
-    if PEAK_DATA in self.inputTypes:
-      self.updatePeakLists()
-      
-    if CONSTRAINT_DATA in self.inputTypes:
-      self.updateConstraintLists()
-      
-    if STRUCTURE_DATA in self.inputTypes:
-      self.updateModels()
-
-    run = self.run
-    
-    structureData = []
-    measurementData = []
-    peakListData = []
-    constraintData = []
-    
-    if run:
-      for dataObj in run.sortedInputs():
-        className = dataObj.className
-        
-        if className == STRUCTURE_DATA:
-          structureData.append(dataObj)
-          
-        elif className == MEASUREMENT_DATA:
-          measurementData.append(dataObj)
-
-        elif className == PEAK_DATA:
-          peakListData.append(dataObj)
-    
-        elif className == CONSTRAINT_DATA:
-          constraintData.append(dataObj)
-    
-    # Structure table
-    if STRUCTURE_DATA in self.inputTypes:
-      textMatrix = []
-      objectList = []
- 
-      for i, dataObj in enumerate(structureData):
-         structure = dataObj.structureEnsemble
-
-         if structure:
-           serials = list(dataObj.modelSerials)
-           
-           if serials:
-             rangeText = getRangeString(serials)
-           else:
-             rangeText = None
-           
-           
-           datum = [i+1,
-                    structure.molSystem.code,
-                    structure.ensembleId,
-                    rangeText]
- 
-         else:
-           datum = [i+1, DATA_MISSING,
-                    None, None]
- 
-         textMatrix.append(datum)
-         objectList.append(dataObj)
- 
-      self.structureTable.update(textMatrix=textMatrix, objectList=objectList)
-
-    # Measurement list table
-    if MEASUREMENT_DATA in self.inputTypes:
-      textMatrix = []
-      objectList = []
-    
-      for i, dataObj in enumerate(measurementData):
-         mList = dataObj.measurementList
-
-         if mList:
- 
-           datum = [i+1, mList.className,
-                    mList.serial,
-                    mList.name,
-                    len(mList.measurements),
-                    mList.details]
- 
-         else:
-           datum = [i+1, DATA_MISSING,
-                    None, None, None, None]
- 
-         textMatrix.append(datum)
-         objectList.append(dataObj)
- 
-      self.measurementsTable.update(textMatrix=textMatrix, objectList=objectList)
-
-    # Peak List Table
-    if PEAK_DATA in self.inputTypes:
-      textMatrix = []
-      objectList = []
- 
-      for i, dataObj in enumerate(peakListData):
-         peakList = dataObj.peakList
-
-         if peakList:
-           serial = peakList.serial
-           spectrum = peakList.dataSource
-           experiment = spectrum.experiment
- 
-           datum = [i+1, experiment.name,
-                    spectrum.name,
-                    serial,
-                    len(peakList.peaks)]
- 
-         else:
-           datum = [i+1, DATA_MISSING,
-                    None, None, None]
- 
-         textMatrix.append(datum)
-         objectList.append(dataObj)
- 
-      self.peakListTable.update(textMatrix=textMatrix, objectList=objectList)
-  
-    # Constraint List Table
-    if CONSTRAINT_DATA in self.inputTypes:
-      textMatrix = []
-      objectList = []
-
-      for i, dataObj in enumerate(constraintData):
-         cSet = dataObj.nmrConstraintStore
-
-         if cSet:
-           constraintLists = dataObj.constraintLists or cSet.sortedConstraintLists()
-         else:
-           constraintLists = []
- 
-         for constraintList in constraintLists:
-           datum = [i+1, constraintList.className[:-14],
-                    cSet.serial,
-                    constraintList.serial,
-                    constraintList.name,
-                    len(constraintList.constraints)]
- 
-           textMatrix.append(datum)
-           objectList.append(dataObj)
- 
-      self.constraintListTable.update(textMatrix=textMatrix, objectList=objectList)
-    
-  
-    # Output table
-    #headingList = ['Data Type','Name','CCPN Data','Parameters','Weight']
-    
-    textMatrix = []
-    objectList = []
-    
-    if run:
-      outputs = run.outputs
-      sortedOutputs = []
-      
-      for dataObj in outputs:
-        dataType = dataObj.className[:-4]
-        serial = dataObj.serial
-        sortedOutputs.append((dataType, serial, dataObj))
-      
-      sortedOutputs.sort()
-      
-      for dataType, serial, dataObj in sortedOutputs:
-        dataObjText = getDataObjText(dataObj)
-      
-        params = []
-        for param in dataObj.runParameters:
-          text = param.code
-          
-          if param.groupId:
-            text += '%d' % param.groupId
-          
-          if param.name:
-            text += ' "%s"'% param.name
-      
-          text += ' Value:'
-          if param.booleanValue is not None:
-            text += param.booleanValue and ' True' or ' False'
-            
-          if param.intValue is not None:
-            text += ' %d' % param.intValue
-
-          if param.floatValue is not None:
-            text += ' %f' % param.floatValue
-
-          if param.textValue is not None:
-            text += param.textValue
-      
-        paramsText = ', '.join(params)
-        
-        textDatum = [dataType, serial,
-                     dataObj.name,
-                     dataObjText,
-                     paramsText,
-                     dataObj.weight]
-        
-        objectList.append(dataObj)
-        textMatrix.append(textDatum)
-        
-    
-    self.outputTable.update(textMatrix=textMatrix, objectList=objectList)
-    self.after_idle(lambda:self.configure(cursor=""))
-    self.waiting = False
-  """
-  
