@@ -19,11 +19,12 @@ from memops.api import Implementation
 
 from ccpnmr.analysis.popups.BasePopup import BasePopup
 from ccpnmr.analysis.core.AssignmentBasic import getResonanceName
-from ccpnmr.analysis.core.MoleculeBasic import getLinkedResidue
 from ccpnmr.analysis.core.ConstraintBasic import angleDifference
-from ccpnmr.analysis.core.StructureBasic import getStructureFromFile
 from memops.editor.Util import createDismissHelpButtonList
 
+from ccp.lib.StructureIo import getStructureFromFile
+from ccp.lib.MoleculeQuery import getLinkedResidue
+
 try:
   from grenoble.c import Meccano
 except Exception, e:
