@@ -44,29 +44,15 @@ automated software development. Bioinformatics 21, 1678-1684.
 ===========================REFERENCE END===============================
  
 """
-from memops.format.compatibility.upgrade.v_2_1_0 import General as General210
-
-# Notes:
-#
-# NmrCalc.MolResidueData.chainCode: non-derived to derived. Should work as is.
-#
-# Never Used (so no compatibility):
-# NmrCalc.MatrixData, cambridge.WmsProtocol
-# Implementation.AbstractMatrix and subclasses (unused or referencedata)
-#
-# Reference data (so no compatibility):
-# NmrReference, StereoChemistry (also never used)
+from memops.format.compatibility.upgrade.v_2_0_5 import General as General205
 
 # functions to convert fullKeys before application
 fullKeyConverters = {}
-fullKeyConverters.update(General210.fullKeyConverters)
+fullKeyConverters.update(General205.fullKeyConverters)
 
 # guids of elements that should be treated as old
-# RunIo.groupId and runIo.weight:
-# Must be kept out of map fixing till the last, as they break it.
-elemsTreatedAsOld = set(('www.ccpn.ac.uk_Fogh_2009-04-16-16:24:04_00031',
-                         'www.ccpn.ac.uk_Fogh_2009-04-16-16:24:03_00012'))
-elemsTreatedAsOld.union(General210.elemsTreatedAsOld)
+elemsTreatedAsOld = set((
+)).union(General205.elemsTreatedAsOld)
 
 # pairs of element guids that should be treated as matching, e.g. whe n
 # a single element must match with several elements in subclasses
@@ -76,9 +62,12 @@ elementPairings = [
 def extraMapChanges(globalMapping):
   """ Extra map changes specific for a given step
   """
-  General210.extraMapChanges(globalMapping)
+  General205.extraMapChanges(globalMapping)
   
   for guid in (
+               # set transferType attributes to delay, to allow resetting
+               "www.ccpn.ac.uk_Fogh_2006-08-16-18:22:58_00022", 
+               "www.ccpn.ac.uk_Fogh_2006-08-16-18:20:07_00001",
                # set links to ExpPrototype package to delay, to allow resetting
                "www.ccpn.ac.uk_Fogh_2006-08-16-18:20:06_00008",
                "www.ccpn.ac.uk_Fogh_2006-08-16-18:23:00_00002",
@@ -86,14 +75,9 @@ def extraMapChanges(globalMapping):
                ):
     globalMapping['mapsByGuid'][guid]['proc'] = 'delay'
     
-  guid = 'www.ccpn.ac.uk_Fogh_2006-08-17-15:11:12_00001'
-  dd = globalMapping['mapsByGuid'][guid]
-  if 'proc' in dd:
-    del dd['proc']  # should not be 'proc':'delay' after all.
-  
-  # skip RunIo.groupId and RunIo.weight.
-  # Not needed, and break normal mechanism as RunIo is not in maps (inherited down)
-  #for guid in ('www.ccpn.ac.uk_Fogh_2009-04-16-16:24:04_00031',
-  #             'www.ccpn.ac.uk_Fogh_2009-04-16-16:24:03_00012'):
-  #  dd = globalMapping['mapsByGuid'][guid]
-  #  dd['proc'] = 'skip'
+  for guid in ('www.ccpn.ac.uk_Fogh_2006-08-17-15:11:12_00001', #Macro.path
+               'www.ccpn.ac.uk_Fogh_2006-08-16-18:23:11_00011', # FixedResonance.name
+               ):
+    dd = globalMapping['mapsByGuid'][guid]
+    if 'proc' in dd:
+      del dd['proc']  # should not be 'proc':'delay' after all.
