@@ -180,7 +180,8 @@ def checkRemoveIfExists(path, removeExisting = False, showYesNo = None):
 
 def saveProject(project, newPath = None, newProjectName = None, changeBackup = True,
                 createFallback = False, removeExisting = False, showYesNo = None,
-                checkValid = False, changeDataLocations = False, showWarning = None):
+                checkValid = False, changeDataLocations = False, showWarning = None,
+                revertToOriginal = False):
   """
   Save the userData for a project to a location given by newPath (the url.path
   of the userData repository) if set, or the existing location if not. 
@@ -209,6 +210,7 @@ def saveProject(project, newPath = None, newProjectName = None, changeBackup = T
       Raise an IOError
   If checkValid then does checkAllValid on project
   If changeDataLocations then copy to project directory
+  If revertToOriginal then after the save changes paths back to as they were originally
   If there is no exception or early return then at end userData is pointing to newPath.
   Return True if save done, False if not (unless there is an exception)
   """
@@ -298,7 +300,7 @@ def saveProject(project, newPath = None, newProjectName = None, changeBackup = T
         print('Copying directory %s to %s (this might take some time if there are big files)' % (oldPath, newPath))
         shutil.copytree(oldPath, newPath)
 
-        # but need to remove all implementation files
+        # but need toz remove all implementation files
         implPath = joinPath(newPath, ImpConstants.modellingPackageName,
                             ImpConstants.implementationPackageName)
         #implPath = pathImplDirectory(newPath)
@@ -449,6 +451,15 @@ def saveProject(project, newPath = None, newProjectName = None, changeBackup = T
         print(xmlUtil.getTopObjectPath(topObject))
       return False
         
+    if revertToOriginal: # TBD: the below does not change back dataUrl paths
+      if newProjectName != oldProjectName:
+        project.__dict__['name'] = oldProjectName  # TBD: for now name is frozen so change this way
+
+      if newPath != oldPath:
+        userData.url = oldUrl
+        if changeBackup:
+          backupRepository.url = oldBackupUrl
+      
     return True
 
   except:
@@ -939,7 +950,7 @@ def modifyPackageLocators(project,repositoryName,repositoryPath,packageNames,res
   
   return repository
   
-def packageProject(project, filePrefix=None, includeBackups=False, includeData=False):
+def packageProject(project, filePrefix=None, includeBackups=False, includeData=False, userPath=None):
   """
   Package up project userData into one gzipped tar file.
   If filePrefix is None then instead use the userData path.
@@ -947,11 +958,13 @@ def packageProject(project, filePrefix=None, includeBackups=False, includeData=F
   By default only *.xml files are packaged up.
   If includeBackups then also *.xml.bak files are included.
   If includeData then also dataStores located inside project directory are included.
+  If userPath is not None then use that instead of userPath.
   """
 
   import tarfile
 
-  userPath = getUserDataPath(project)
+  if not userPath:
+    userPath = getUserDataPath(project)
   userDir = os.path.dirname(userPath)
 
   if includeData:
