@@ -93,7 +93,8 @@ class PulldownMenu(Frame):
     if (entries is None):
       entries = []
 
-    Frame.__init__(self, parent, sticky=sticky, docKey=docKey, tipText=tipText, createToolTip=True, *args, **kw)
+    Frame.__init__(self, parent, sticky=sticky, docKey=docKey, tipText=tipText,
+                   createToolTip=True, *args, **kw)
 
     self.text_attr = text_attr
 
