@@ -629,7 +629,7 @@ class Scrollbar(Frame):
         (abs(hi - self.hi) < min_delta)):
       return
 
-    if (self.min_thickness and (hi-lo) < (self.min_thickness-min_delta)):
+    if (self.min_thickness and (hi-lo) < 0.1*self.min_thickness):
       # here have new small thickness, but only do something if existing position not minimal
       # or if expanding rather than contracting region (can happen that min_thickness jumps up)
       #if ((self.hi - self.lo) > (self.min_thickness + min_delta)):
