@@ -12,6 +12,7 @@ Does no output.
 
 from memops.universal import Util as uniUtil
 from memops.metamodel import MetaModel
+from memops.metamodel import Util as metaUtil
 MemopsError = MetaModel.MemopsError
 from memops.metamodel import ImpConstants
 from memops.metamodel.ModelPortal import ModelPortal
@@ -358,51 +359,31 @@ class ModelTraverse_py_2_1:
 
   ###########################################################################
     
-  def getOperation(self, target, opType, inClass=None, opSubType=None):
-    """ get existing operation. If none found return None
-    """
-    
-    if inClass is None:
-      if isinstance(target, MetaModel.ComplexDataType):
-        inClass = target
-      else:
-        inClass = target.container
-    
-    for op in inClass.getAllOperations():
-      if ((op.target) is target and op.opType == opType
-          and op.opSubType == opSubType):
-        return op
-    #
-    return None
-    
-  ###########################################################################
-
-  ###########################################################################
-    
   def getFuncname(self, op, inClass=None):
     """ get function calling name for operation
     
     the name is the operation name of the corresponding operation with
     opSubType==None
     """
-    if inClass is None:
-      inClass = op.container
-    
-    if not isinstance(op, MetaModel.MetaOperation):
-      raise MemopsError("Illegal parameter for getFuncname : %s" % `op`)
-    
-    if op.opSubType is not None:
-      op = self.getOperation(op.target, op.opType, inClass)
-    #
-    if op is None:
-      raise MemopsError("No operation with opSubType None corresponds to %s"
-       % op.qualifiedName()
-      )
-    else:
-      return op.name
+    return metaUtil.getFuncname(op, inClass)
     
   ###########################################################################
 
+  ###########################################################################
+
+  def valueVar(self, element, doInstance=False, prefix=''):
+
+    var = self.varNames['value']
+    if (not doInstance and element.hicard != 1):
+      var = self.varNames['values']
+
+    if prefix:
+      var = prefix + uniUtil.upperFirst(var)
+
+    return var
+
+  ###########################################################################
+
   ###########################################################################
     
   def defineFunc(self, op):
@@ -421,36 +402,6 @@ class ModelTraverse_py_2_1:
 
   ###########################################################################
 
-  def getReturnPar(self, op):
-    """ select and return MetaParameter with direction 'return', if any
-    """
-
-    for par in op.parameters:
-      
-      if par.direction == ImpConstants.return_direction:
-        return par
-    
-    return None
-
-  ###########################################################################
-
-  ###########################################################################
-
-  def valueVar(self, element, doInstance=False, prefix=''):
-
-    var = self.varNames['value']
-    if (not doInstance and element.hicard != 1):
-      var = self.varNames['values']
-
-    if prefix:
-      var = prefix + uniUtil.upperFirst(var)
-
-    return var
-
-  ###########################################################################
-
-  ###########################################################################
-
   def getImportName(self, oo, pp=None, subDirs=None):
     
     if subDirs is None:
@@ -464,38 +415,7 @@ class ModelTraverse_py_2_1:
       oo = oo.getElement(ImpConstants.modellingPackageName)
       
         
-    return self.getReferenceName(oo, pp, subDirs=subDirs)
-
-  ###########################################################################
-
-  ###########################################################################
-
-  def getReferenceName(self, oo, pp=None, subDirs=None):
-    """ get name to refer to an object oo from package pp
-    If pp is not None the routine will return a short form of the name whenever
-    oo is contained within pp.
-    Otherwise the routine returns the full import name.
-    NB the function is used also to generate names for documentation.
-    Unless oo is an object contained within a package, the result will
-    not be valid for the purpose of importing oo.
-    """
-
-    if (pp is not None and (oo.container is pp)):
-      # pp passed in and oo directly available from pp. Return short name
-      name = oo.name
-    else:
-      # no shortcuts - return fully qualified import name
-      qname = oo.qualifiedName()
-      if qname == '':
-        name = qname
-      elif subDirs:
-        pathList = qname.split('.')
-        pathList[1:1] = subDirs
-        name = '.'.join(pathList)
-      else:
-        name = qname
-
-    return name
+    return metaUtil.getReferenceName(oo, pp, subDirs=subDirs)
 
   ###########################################################################
   
@@ -685,22 +605,3 @@ class ModelTraverse_py_2_1:
     return self.comparison(var, 'is not', self.noneValue)
 
   ###########################################################################
-
-  ###########################################################################
-
-  def coerceToList(self, params):
-    
-    # wrap non-iterables into list
-    if (params is None):
-      params = []
-    elif isinstance(params, basestring):
-      params = [params]
-    else:
-      try:
-        params = list(params)
-      except:
-        params = [params]
-    #
-    return params
-
-  ###########################################################################
