@@ -206,11 +206,14 @@ class XmlModelRead(TextWriter_py_2_1.TextWriter_py_2_1):
     guid='www.ccpn.ac.uk_RasmusFogh_2006-06-21-19:13:29_00000',
      taggedValues={'packageGroup':TaggedValues.defaultPackageGroup}
     )
-    rootfile = self.getObjFileName(dummy, addSuffix=True)
+    if hasattr(self, 'rootFile') and self.rootFile:
+      rootFile = self.rootFile
+    else:
+      rootFile = self.getObjFileName(dummy, addSuffix=True)
     del dummy
     
     # parse XML file and recurse over xIncluded files
-    self.loadXmlFile(rootfile)
+    self.loadXmlFile(rootFile)
     
     # load delayed data
     self.loadDelayedData()
@@ -329,6 +332,9 @@ class XmlModelRead(TextWriter_py_2_1.TextWriter_py_2_1):
       # handle contained elements
       for elem in modelElem:
         tag = elem.tag
+        # lxml also provides comments in addition to normal content
+        if tag is ElementTree.Comment:
+          continue
         if classNameMapping.get(tag) is None:
           # Element content - handle directly
         
