@@ -5,7 +5,6 @@ import os, sys, json, re, time
 import tarfile, zipfile, bz2, gzip, shutil
 import traceback
 
-from ccpnmr.lib import StructureBasic
 from ccp.general import Io as genIo
 #from memops.general import Io as genIo
 from nijmegen.CASD import Constants as casdConstants
@@ -238,85 +237,6 @@ def getInputFile(identifier, subdir, ignoreErrors=False):
     raise Exception("Contents of %s not a single file: %s." % (path, ll))
   #
   return result
-
-def loadPdbFiles(molSystem, pdbPaths):
-  """ Load several PDB files, trying (in order) true pdb, cns, rough
-  Takes the first model from each file
-  """
-  
-  data = {}
-  modelNames = []
-  
-  nSkipped = 0
-  modelNum = 0
-  for pdbPath in pdbPaths:
-    
-    # Load data
-    try:
-      print '### trying pdb'
-      dd = StructureBasic.makeStructureDictFromPdb(pdbPath, 'pdb')
-    except:
-      dd = None
- 
-    if not dd:
-      print '### trying rough'
-      dd = StructureBasic.makeStructureDictFromRoughPdb(pdbPath)
- 
-    if dd:
-      #
-      data[modelNum] = dd[0]
- 
-      # append model name
-      basename = os.path.basename(pdbPath)
-      indx = basename.find('.pdb')
-      if indx > 0:
-        modelName = basename[:indx]
-      else:
-        modelName, ext = os.path.splitext(basename)
-      modelNames.append(modelName)
-      
-      modelNum += 1
-      
-    else:
-      nSkipped += 1
-      print ('Error coordinate read failed. Skipping %s'
-             % pdbPath)
-      
-  # make ensemble
-  
-  if data:
-    if nSkipped:
-      print 'WARNING, %s files skipped' % nSkipped
-    return StructureBasic.makeStructureEnsemble(data, 
-                                                molSystem, 
-                                                modelNames=modelNames)
-  
-  else:
-    raise Exception("ERROR PDB data read, %s files skipped" % nSkipped)
-  
-    
-def loadPdbFile(molSystem, pdbPath):
-  """ Load all models from PDB file, trying (in order) true pdb, rough
-  Takes the first model from each file
-  """
-    
-  # Load data
-  try:
-    print '### trying pdb'
-    data = StructureBasic.makeStructureDictFromPdb(pdbPath, 'pdb')
-  except:
-    data = None
-      
-  if not data:
-    print '### trying rough'
-    data = StructureBasic.makeStructureDictFromRoughPdb(pdbPath)
-  
-  if not data:
-    raise Exception ('ERROR coordinate read failed, no data')
-  
-  # make ensemble
-  print '### models;', sorted(data.keys())
-  return StructureBasic.makeStructureEnsemble(data, molSystem)
     
 
 def getLowestSubDir(inputDir, followDirs=None):
