@@ -372,6 +372,7 @@ def makeCcpnProject(entryName):
         
         else:
           # FormatConverter version
+          restraintLists = []
           for rfile in restraintFiles:
             rpath = os.path.join(tmprestr,rfile)
             fileInfo = fcw.determineFileInfo(rpath)
@@ -387,14 +388,20 @@ def makeCcpnProject(entryName):
             else:
               print 'Reading restraint file', dataType, formatName, rfile
               fcw.readFile(dataType, formatName, rpath)
-              print fcw.ccpnObjectOrList
-              print fcw.conversionInfo
-              print fcw.conversionSuccess
+              if fcw.conversionSuccess:
+                print ("Successful restraint file read:\n%s" % fcw.conversionInfo)
+                restraintLists.append(fcw.ccpnObjectOrList)
+              else:
+                print ("Failed restraint file read:\n%s" % fcw.conversionInfo)
+
+          if restraintLists:
+            print ("Found restraint lists: %s" % len(restraintLists))
+            casdRun.newConstraintStoreData(constraintLists=restraintLists, name='Restraintlists')
+
         
         # linkResonances
         print '### linking resonances'
         linkingInfo = fcw.linkAllResonancesToAtoms()
-        print linkingInfo
 
     finally:
         shutil.rmtree(tmpdir, ignore_errors=True)
@@ -712,9 +719,8 @@ if __name__ == '__main__':
   #entryList = ['2ltm_Piscataway_279']
   #entryList = ['2m5o_Paris_303']
   #entryList = ['2m5o_Piscataway_301']
-  #entryList = sorted(list(x for x in calcData.keys() if not x.endswith('_Org')))
+  entryList = sorted(list(x for x in calcData.keys() if not x.endswith('_Org')))
   #entryList = ['2la6_Paris_144', '2l9r_Piscataway_135', '2m5o_Paris_303']
-  entryList = ['2m5o_Paris_303']
 
   for entryName in entryList:
     makeCcpnProject(entryName)
