@@ -27,7 +27,9 @@ from nijmegen.cing import iCingRobot
 # Retrieve ROG results
 # Store calc params
 
-URLS = ['https://nmr.cmbi.ru.nl/', 'http://nmr.cmbi.ru.nl/']
+#URLS = ['https://nmr.cmbi.ru.nl/', 'http://nmr.cmbi.ru.nl/']
+# from January 2014
+URLS = ['https://nmr.le.ac.uk/']
 DEFAULT_URL = URLS[0]
 
 CING_BLUE = '#78B8F0'
@@ -274,7 +276,7 @@ class CingFrame(NmrCalcRunFrame):
   
   def getServerUrl(self, baseUrl):
     
-    iCingUrl = os.path.join(baseUrl, 'icing/serv/iCingServlet')
+    iCingUrl = os.path.join(baseUrl, 'icing/icing/serv/iCingServlet')
     return iCingUrl
     
   def viewHtmlResults(self):
