@@ -86,6 +86,10 @@ class CingPopup(BasePopup):
     self.frame = CingFrame(guiFrame, self.parent, closeButton=True)
     self.frame.grid(row=0, column=0, sticky='nsew')
     self.frame.updateAll()
+    # wb104 9 Feb 2015
+    # not sure why, but need below as well as grid above or otherwise
+    # just get blank dialog until it is resized
+    self.after_idle(lambda: self.frame.grid(row=0, column=0, sticky='nsew'))
   
   def open(self):
   
