@@ -254,15 +254,17 @@ def _packageProject(memopsRoot):
         newProjDir = os.path.join(parentDir, newProjName)
     
     try:
-      saveProject(memopsRoot, newPath=newProjDir, removeExisting=True)
+      saveProject(memopsRoot, newPath=newProjDir, removeExisting=True, revertToOriginal=True)
     
-      packageProject(memopsRoot, newProjDir)
+      packageProject(memopsRoot, filePrefix=newProjDir, userPath=newProjDir)
     finally:
       # reset project name
       # need to use override since name is frozen
-      memopsRoot.override = True
-      memopsRoot.name = currentProjName
-      memopsRoot.override = False
+      # wb104: 6 Feb 2014: should not need to do below any more because added revertToOriginal and userPath above
+      #memopsRoot.override = True
+      #memopsRoot.name = currentProjName
+      #memopsRoot.override = False
+      pass
 
     return newProjDir + '.tgz'
 
