@@ -7,7 +7,7 @@ import os, re
 
 from memops.api import Implementation
 from ccp.format.general.Constants import defaultSeqInsertCode, defaultMolCode
-from ccp.general.Util import findAllSysNamesByChemAtoms, findChemCompSysName
+from ccp.general.Util import findAllSysNamesByChemAtomOrSet, findChemCompSysName
 
 from ccpnmr.format.general.Constants import assign_kw
 
@@ -1939,7 +1939,7 @@ class NmrStarExport:
             chemCompVar = residue.residue.chemCompVar
   
             if not self.chemAtomSysNamesDict.has_key(chemCompVar):
-              chemAtomSysNames = findAllSysNamesByChemAtoms(chemCompVar.chemComp,chemCompVar.chemAtoms,namingSystemName)
+              chemAtomSysNames = findAllSysNamesByChemAtomOrSet(chemCompVar.chemComp,chemCompVar.chemAtoms,namingSystemName)
               self.chemAtomSysNamesDict[chemCompVar] = chemAtomSysNames
             else:
               chemAtomSysNames = self.chemAtomSysNamesDict[chemCompVar]
