@@ -39,9 +39,11 @@ ccpnmr_rel_dir = 'ccpnmr%s' % ccpnmr_version
 #tcltk_release = '8.3.4'
 #tcltk_version = '8.4'
 #tcltk_release = '8.4.14'
-tcltk_version = '8.5'
+#tcltk_version = '8.5'
 #tcltk_release = '8.5.4'
-tcltk_release = '8.5.8'
+#tcltk_release = '8.5.8'
+tcltk_version = '8.6'
+tcltk_release = '8.6.3'
 
 tcl_rel_dir = 'tcl%s' % tcltk_version
 tcl_tar_dir = 'tcl%s' % tcltk_release
@@ -68,10 +70,10 @@ min_python_version = '2.4'
 #python_release = '2.4.2'
 #python_version = '2.5'
 #python_release = '2.5.2'
-python_version = '2.6'
-python_release = '2.6.5'
-#python_version = '2.7'
-#python_release = '2.7.6'
+#python_version = '2.6'
+#python_release = '2.6.5'
+python_version = '2.7'
+python_release = '2.7.9'
 python_rel_dir = 'python%s' % python_version
 python_tar_dir = 'Python-%s' % python_release
 python_tar_file = python_tar_dir + '.tar'
@@ -84,8 +86,10 @@ element_tree_tar_file_gz = element_tree_tar_file + '.gz'
 
 #numpy_version = '1.2'
 #numpy_release = '1.2.1'
-numpy_version = '1.4'
-numpy_release = '1.4.1'
+#numpy_version = '1.4'
+#numpy_release = '1.4.1'
+numpy_version = '1.9'
+numpy_release = '1.9.2'
 numpy_rel_dir = 'numpy%s' % numpy_version
 numpy_tar_dir = 'numpy-%s' % numpy_release
 numpy_tar_file = numpy_tar_dir + '.tar'
@@ -437,6 +441,7 @@ def compileTix(softwareDict):
   tcl_abs_dir  = tclCodeDict.get('directory')
   tcl_lib_dir = tclCodeDict['lib']
   tcl_lib_dir = os.path.join(tcl_abs_dir, tcl_lib_dir)
+  tcltk_version = tclCodeDict['version']
 
   tkCodeDict = softwareDict['Tk']
   tk_abs_dir  = tkCodeDict.get('directory')
@@ -453,6 +458,9 @@ def compileTix(softwareDict):
     if n >= 10:  # OSX >= 10.6 (Snow Leopard)
       flags += ' --enable-64bit'
     
+  if tcltk_version == '8.6':
+    flags += ' CC="gcc -DUSE_INTERP_RESULT -DUSE_INTERP_ERRORLINE"'
+
   cmds = []
   cmds.append('./configure --prefix=%s/%s --with-tcl=%s --with-tk=%s --x-includes=%s --x-libraries=%s %s' % (top_dir, tix_rel_dir, tcl_lib_dir, tk_lib_dir, x11_inc_dir, x11_lib_dir, flags))
   cmds.append('make')
@@ -519,6 +527,10 @@ def compilePython(softwareDict):
   codeDict = softwareDict['X11']
   x11_abs_dir  = codeDict.get('directory')
 
+  platform = getPlatform()
+  bits = softwareDict['bits']
+  built_by = os.environ.get('USER', 'unknown')
+
   if x11_abs_dir:
 
     # need to create Modules/Setup so that our Tcl/Tk found
@@ -548,7 +560,9 @@ def compilePython(softwareDict):
 
     fp = open('Modules/Setup.dist', 'w')
     s = '# The _tkinter module.'
+    t = '#SSL=/usr/local/ssl'
     n = len(s)
+    m = len(t)
     for line in lines:
       fp.write(line)
       if (line[:n] == s):
@@ -562,11 +576,20 @@ def compilePython(softwareDict):
 ''' % (tcl_abs_dir, tcl_lib_dir, tk_abs_dir, tk_lib_dir, x11_abs_dir, x11_lib_dir,
        tcl_abs_dir, tcl_inc_dir, tk_abs_dir, tk_inc_dir, x11_abs_dir, x11_inc_dir,
        tix_stuff, tcltk_version, tcltk_version))
+      elif (platform == 'linux') and (bits == 64) and (built_by == 'wb104') and (line[:m] == t): # 2015 Feb 24 hack to get ssl compilation to work on hydra (also needed to edit out SSL2 stuff from Python source code: see http://blog.schmichael.com/2012/05/29/building-python-2-6-8-on-ubuntu-12-04/, although 2.6.5 is somewhat different)
+        fp.write('''
+# lines below added in by CcpNmr installation script
+SSL=/usr
+_ssl _ssl.c \
+       -DUSE_SSL -I$(SSL)/include -I$(SSL)/include/openssl \
+       -L$(SSL)/lib -lssl -lcrypto
+
+_hashlib _hashopenssl.c
+''')
     fp.close()
 
   # now compile and install code
 
-  platform = getPlatform()
   flags = ''
   if platform == 'darwin':
     flags = ' --enable-threads --disable-toolbox-glue --disable-framework'
